AlternateMailbox class

Represents an alternate mailbox.

Properties

DisplayName ↔ String?
Gets the alternate mailbox display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
LegacyDN ↔ String?
Gets the alternate mailbox legacy DN.
getter/setter pair
OwnerSmtpAddress ↔ String?
Gets the alternate mailbox owner SmtpAddress.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server ↔ String?
Gets the alernate mailbox server.
getter/setter pair
SmtpAddress ↔ String?
Gets the alternate mailbox address. It has value only when Server and LegacyDN is empty.
getter/setter pair
Type ↔ String?
Gets the alternate mailbox type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

LoadFromXml(EwsXmlReader reader) → Future<AlternateMailbox>
Loads AlternateMailbox instance from XML.