AutodiscoverError class

Represents an error returned by the Autodiscover service.

Properties

DebugData → String?
Gets the debug data.
no setter
ErrorCode → int?
Gets the error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
Id → String?
Gets a hash of the name of the computer that is running Microsoft Exchange Server that has the Client Access server role installed.
no setter
Message → String?
Gets the error message.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Time → String?
Gets the time when the error was returned.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Parse(EwsXmlReader reader) → AutodiscoverError
Parses the XML through the specified reader and creates an Autodiscover error.