AutodiscoverResponseCollection<TResponse extends AutodiscoverResponse> class abstract

Represents a collection of responses to a call to the Autodiscover service.
Inheritance
Mixed-in types
Implementers

Constructors

AutodiscoverResponseCollection()
Initializes a new instance of the

Properties

Count → int
Gets the number of responses in the collection.
no setter
ErrorCode ↔ AutodiscoverErrorCode?
Gets the error code that was returned by the service.
getter/setter pairinherited
ErrorMessage ↔ String?
Gets the error message that was returned by the service.
getter/setter pairinherited
first → TResponse
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<TResponse>
Gets an enumerator that iterates through the elements of the collection.
no setteroverride
last → TResponse
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
RedirectionUrl ↔ Uri?
Gets or sets the redirection URL.
getter/setter pairinherited
Responses → List<TResponse>?
Gets the responses list.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → TResponse
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(TResponse element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
CreateResponseInstance() → TResponse
Create a response instance.
elementAt(int index) → TResponse
Returns the indexth element.
inherited
every(bool test(TResponse element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(TResponse element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(TResponse element), {TResponse orElse()?}) → TResponse
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, TResponse element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<TResponse> other) → Iterable<TResponse>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(TResponse element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
GetResponseCollectionXmlElementName() → String
Gets the name of the response collection XML element.
GetResponseInstanceXmlElementName() → String
Gets the name of the response instance XML element.
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(TResponse element), {TResponse orElse()?}) → TResponse
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsXmlReader reader, String endElementName) → void
Loads response from XML.
override
LoadResponseCollectionFromXml(EwsXmlReader reader) → void
Loads the response collection from XML.
map<T>(T toElement(TResponse e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(TResponse combine(TResponse value, TResponse element)) → TResponse
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(TResponse element), {TResponse orElse()?}) → TResponse
The single element that satisfies test.
inherited
skip(int count) → Iterable<TResponse>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(TResponse element)) → Iterable<TResponse>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<TResponse>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(TResponse element)) → Iterable<TResponse>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<TResponse>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<TResponse>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(TResponse element)) → Iterable<TResponse>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → TResponse
Gets the response at the specified index.