ConfigurationSettingsBase class abstract

Represents the base class for configuration settings.
Implementers

Constructors

ConfigurationSettingsBase()
Initializes a new instance of the

Properties

Error → AutodiscoverError?
Gets the error.
no setter
hashCode → int
The hash code for this object.
no setterinherited
RedirectTarget → String?
Gets the redirect target.
no setter
ResponseType → AutodiscoverResponseType?
Gets the type of the response.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ConvertSettings(String smtpAddress, List<UserSettingName> requestedSettings) → GetUserSettingsResponse
Convert ConfigurationSettings to GetUserSettings response.
GetNamespace() → String
Gets the namespace that defines the settings.
LoadFromXml(EwsXmlReader reader) → void
Loads the settings from XML.
MakeRedirectionResponse(Uri redirectUrl) → void
Makes this instance a redirection response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
TryReadCurrentXmlElement(EwsXmlReader reader) → bool
Tries to read the current XML element.

Operators

operator ==(Object other) → bool
The equality operator.
inherited