DomainSettingError class

Represents an error from a GetDomainSettings request.

Constructors

DomainSettingError()
Initializes a new instance of the

Properties

ErrorCode → AutodiscoverErrorCode?
Gets the error code.
no setter
ErrorMessage → String?
Gets the error message.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SettingName → String?
Gets the name of the setting.
no setter

Methods

LoadFromXml(EwsXmlReader reader) → void
Loads from XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited