ProtocolConnection class

Represents the email Protocol connection settings for pop/imap/smtp protocols.

Constructors

ProtocolConnection()
Initializes a new instance of the
ProtocolConnection.withEncryptionMethodAndHostnameAndPort(String encryptionMethod, String hostname, int port)
Initializes a new instance of the

Properties

EncryptionMethod ↔ String?
Gets or sets the encryption method.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Hostname ↔ String?
Gets or sets the Hostname.
getter/setter pair
Port ↔ int?
Gets or sets the port number.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

LoadFromXml(EwsXmlReader reader) → ProtocolConnection
Read user setting with ProtocolConnection value.