AutodiscoverRequest class abstract

Represents the base class for all requested made to the Autodiscover service.
Implementers

Constructors

AutodiscoverRequest(AutodiscoverService _service, Uri? _url)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → AutodiscoverService
Gets the service.
no setter
Url → Uri?
Gets the URL.
no setter

Methods

CreateRedirectionResponse(IEwsHttpWebResponse httpWebResponse) → AutodiscoverResponse?
Create a redirection response.
CreateServiceResponse() → AutodiscoverResponse
Creates the service response.
GetRequestXmlElementName() → String
Gets the name of the request XML element.
GetResponseXmlElementName() → String
Gets the name of the response XML element.
GetWsAddressingActionName() → String
Gets the WS-Addressing action name.
InternalExecute() → Future<AutodiscoverResponse>
Executes this instance.
LoadFromXml(EwsXmlReader reader) → Future<AutodiscoverResponse>
Loads responses from XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ProcessWebException(WebException webException) → Future<void>
Processes the web exception.
ReadServerVersionInfo(EwsXmlReader reader) → Future<ExchangeServerInfo>
Read ServerVersionInfo SOAP header.
ReadSoapBody(EwsXmlReader reader) → Future<AutodiscoverResponse>
Read SOAP body.
ReadSoapFault(EwsXmlReader reader) → Future<SoapFaultDetails?>
Reads the SOAP fault.
ReadSoapHeader(EwsXmlReader reader) → Future<void>
Reads a single SOAP header.
ReadSoapHeaders(EwsXmlReader reader) → Future<void>
Read SOAP headers.
toString() → String
A string representation of this object.
inherited
Validate() → void
Validates the request.
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes attributes to request XML.
WriteBodyToXml(EwsServiceXmlWriter writer) → void
Writes XML body.
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to request XML.
WriteExtraCustomSoapHeadersToXml(EwsServiceXmlWriter writer) → void
Write extra headers.
WriteSoapRequest(Uri? requestUrl, EwsServiceXmlWriter writer) → void
Writes the autodiscover SOAP request.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

GetResponseStream(IEwsHttpWebResponse response) → Stream
Gets the response stream (may be wrapped with GZip/Deflate stream to decompress content)
IsRedirectionResponse(IEwsHttpWebResponse httpWebResponse) → bool
Determines whether response is a redirection.