GetUserSettingsRequest class

Represents a GetUserSettings request.
Inheritance

Constructors

GetUserSettingsRequest(AutodiscoverService service, Uri? url, [bool expectPartnerToken = false])
Initializes a new instance of the

Properties

expectPartnerToken → bool
Expect this request to return the partner token.
final
hashCode → int
The hash code for this object.
no setterinherited
PartnerToken ↔ String?
Gets the partner token.
getter/setter pair
PartnerTokenReference ↔ String?
Gets the partner token reference.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → AutodiscoverService
Gets the service.
no setterinherited
Settings ↔ List<UserSettingName>?
Gets or sets the settings.
getter/setter pair
SmtpAddresses ↔ List<String>?
Gets or sets the SMTP addresses.
getter/setter pair
Url → Uri?
Gets the URL.
no setterinherited

Methods

CreateRedirectionResponse(IEwsHttpWebResponse httpWebResponse) → AutodiscoverResponse?
Create a redirection response.
inherited
CreateServiceResponse() → AutodiscoverResponse
Creates the service response.
override
Execute() → Future<GetUserSettingsResponseCollection>
Executes this instance.
GetRequestXmlElementName() → String
Gets the name of the request XML element.
override
GetResponseXmlElementName() → String
Gets the name of the response XML element.
override
GetWsAddressingActionName() → String
Gets the WS-Addressing action name.
override
InternalExecute() → Future<AutodiscoverResponse>
Executes this instance.
inherited
LoadFromXml(EwsXmlReader reader) → AutodiscoverResponse
Loads responses from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
PostProcessResponses(GetUserSettingsResponseCollection responses) → void
Post-process responses to GetUserSettings.
ProcessWebException(WebException webException) → Future<void>
Processes the web exception.
inherited
ReadServerVersionInfo(EwsXmlReader reader) → ExchangeServerInfo
Read ServerVersionInfo SOAP header.
inherited
ReadSoapBody(EwsXmlReader reader) → AutodiscoverResponse
Read SOAP body.
inherited
ReadSoapFault(EwsXmlReader reader) → SoapFaultDetails?
Reads the SOAP fault.
inherited
ReadSoapHeader(EwsXmlReader reader) → void
Read the partner token soap header.
override
ReadSoapHeaders(EwsXmlReader reader) → void
Read SOAP headers.
inherited
toString() → String
A string representation of this object.
inherited
Validate() → void
Validates the request.
override
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteBodyToXml(EwsServiceXmlWriter writer) → void
Writes XML body.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes request to XML.
override
WriteExtraCustomSoapHeadersToXml(EwsServiceXmlWriter writer) → void
override
WriteSoapRequest(Uri? requestUrl, EwsServiceXmlWriter writer) → void
Writes the autodiscover SOAP request.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

GetUserSettingsActionUri → const String
Action Uri of Autodiscover.GetUserSettings method.