GetUserSettingsResponse class

Represents the response to a GetUsersSettings call for an individual user.
Inheritance

Constructors

GetUserSettingsResponse()
Initializes a new instance of the

Properties

ErrorCode ↔ AutodiscoverErrorCode?
Gets the error code that was returned by the service.
getter/setter pairinherited
ErrorMessage ↔ String?
Gets the error message that was returned by the service.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
RedirectionUrl ↔ Uri?
Gets or sets the redirection URL.
getter/setter pairinherited
RedirectTarget ↔ String?
Gets the redirectionTarget (URL or email address)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Settings ↔ Map<UserSettingName?, Object?>
Gets the requested settings for the user.
getter/setter pair
SmtpAddress ↔ String?
Gets the SMTP address this response applies to.
getter/setter pair
UserSettingErrors ↔ List<UserSettingError>
Gets error information for settings that could not be returned.
getter/setter pair

Methods

LoadFromXml(EwsXmlReader reader, String endElementName) → void
Loads response from XML.
override
LoadUserSettingsFromXml(EwsXmlReader reader) → void
Loads from XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
TryGetSettingValue<T>(UserSettingName setting, OutParam<T>? valueOutParam) → bool
Tries the get the user setting value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited