GetUserSettingsResponseCollection class

Represents a collection of responses to GetUserSettings
Inheritance

Constructors

GetUserSettingsResponseCollection()
Initializes a new instance of the

Properties

Count → int
Gets the number of responses in the collection.
no setterinherited
ErrorCode ↔ AutodiscoverErrorCode?
Gets the error code that was returned by the service.
getter/setter pairinherited
ErrorMessage ↔ String?
Gets the error message that was returned by the service.
getter/setter pairinherited
first → GetUserSettingsResponse
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<GetUserSettingsResponse>
Gets an enumerator that iterates through the elements of the collection.
no setterinherited
last → GetUserSettingsResponse
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
RedirectionUrl ↔ Uri?
Gets or sets the redirection URL.
getter/setter pairinherited
Responses → List<GetUserSettingsResponse>?
Gets the responses list.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → GetUserSettingsResponse
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(GetUserSettingsResponse element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
CreateResponseInstance() → GetUserSettingsResponse
Create a response instance.
override
elementAt(int index) → GetUserSettingsResponse
Returns the indexth element.
inherited
every(bool test(GetUserSettingsResponse element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(GetUserSettingsResponse element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(GetUserSettingsResponse element), {GetUserSettingsResponse orElse()?}) → GetUserSettingsResponse
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, GetUserSettingsResponse element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<GetUserSettingsResponse> other) → Iterable<GetUserSettingsResponse>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(GetUserSettingsResponse element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
GetResponseCollectionXmlElementName() → String
Gets the name of the response collection XML element.
override
GetResponseInstanceXmlElementName() → String
Gets the name of the response instance XML element.
override
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(GetUserSettingsResponse element), {GetUserSettingsResponse orElse()?}) → GetUserSettingsResponse
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsXmlReader reader, String endElementName) → void
Loads response from XML.
inherited
LoadResponseCollectionFromXml(EwsXmlReader reader) → void
Loads the response collection from XML.
inherited
map<T>(T toElement(GetUserSettingsResponse e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(GetUserSettingsResponse combine(GetUserSettingsResponse value, GetUserSettingsResponse element)) → GetUserSettingsResponse
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(GetUserSettingsResponse element), {GetUserSettingsResponse orElse()?}) → GetUserSettingsResponse
The single element that satisfies test.
inherited
skip(int count) → Iterable<GetUserSettingsResponse>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(GetUserSettingsResponse element)) → Iterable<GetUserSettingsResponse>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<GetUserSettingsResponse>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(GetUserSettingsResponse element)) → Iterable<GetUserSettingsResponse>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<GetUserSettingsResponse>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<GetUserSettingsResponse>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(GetUserSettingsResponse element)) → Iterable<GetUserSettingsResponse>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → GetUserSettingsResponse
Gets the response at the specified index.
inherited