WebClientUrl class

Represents the URL of the Exchange web client.

Constructors

WebClientUrl(String? authenticationMethods, String? url)
Initializes a new instance of the

Properties

AuthenticationMethods ↔ String?
Gets the authentication methods.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Url ↔ String?
Gets the URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

LoadFromXml(EwsXmlReader reader) → Future<WebClientUrl>
Loads WebClientUrl instance from XML.