Attachment class abstract

Represents an attachment to an item.
Inheritance
Implementers

Constructors

Attachment.withExchangeService(ExchangeService _service)
Initializes a new instance of the
Attachment.withOwner(Item owner)
Initializes a new instance of the

Properties

ContentId ↔ String?
Gets or sets the content Id of the attachment. ContentId can be used as a custom way to identify an attachment in order to reference it from within the body of the item the attachment belongs to.
getter/setter pair
ContentLocation ↔ String?
Gets or sets the content location of the attachment. ContentLocation can be used to associate an attachment with a Url defining its location on the Web.
getter/setter pair
ContentType ↔ String?
Gets or sets the content type of the attachment.
getter/setter pair
DateTime ← DateTime
no getter
hashCode → int
The hash code for this object.
no setterinherited
Id ↔ String?
Gets the Id of the attachment.
getter/setter pair
IsInline ↔ bool?
Gets or sets a value indicating whether this is an inline attachment. Inline attachments are not visible to end users.
getter/setter pair
IsNew → bool
True if the attachment has not yet been saved, false otherwise.
no setter
LastModifiedTime → DateTime?
Gets the date and time when this attachment was last modified.
no setter
Name ↔ String?
Gets or sets the name of the attachment.
getter/setter pair
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
Owner → Item?
Gets the owner of the attachment.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Gets the related exchange service.
no setter
Size ↔ int?
Gets the size of the attachment.
getter/setter pair

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
override
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
InternalLoad(BodyType? bodyType, Iterable<PropertyDefinitionBase>? additionalProperties) → Future<void>
Load the attachment.
InternalValidate() → void
Validates this instance.
inherited
Load() → Future<void>
Loads the attachment. Calling this method results in a call to EWS.
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
ThrowIfThisIsNotNew() → void
Throws exception if this is not a new service object.
toString() → String
A string representation of this object.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
ValidateWithIndex(int attachmentIndex) → void
Validates this instance.
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited