AttachmentCollection class

Represents an item's attachment collection.
Inheritance
Implemented types

Constructors

AttachmentCollection()
Initializes a new instance of AttachmentCollection.

Properties

AddedItems → List<Attachment>
Gets the added items.
no setterinherited
Count → int
Gets the total number of properties in the collection.
no setterinherited
first → Attachment
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
Items → List<Attachment>
Gets the items.
no setterinherited
iterator → Iterator<Attachment>
Gets an enumerator that iterates through the elements of the collection.
no setterinherited
last → Attachment
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
ModifiedItems → List<Attachment>
Gets the modified items.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
Owner ↔ ServiceObject?
The owner of this attachment collection.
getter/setter pairoverride
RemovedItems → List<Attachment?>
Gets the removed items.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → Attachment
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

AddFileAttachmentWithContent(String name, Uint8List content) → FileAttachment
Adds a file attachment to the collection.
AddFileAttachmentWithStream(String name, Stream contentStream) → FileAttachment
Adds a file attachment to the collection.
addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
any(bool test(Attachment element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
Changed() → dynamic
Instance was changed.
inherited
Clear() → void
Adds a reference attachment to the collection
ClearChangeLog() → void
Disables the change log clearing mechanism. Attachment collections are saved separately from the items they belong to.
override
Contains(Attachment complexProperty) → bool
Determines whether a specific property is in the collection.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
CreateComplexProperty(String xmlElementName) → Attachment?
Instantiate the appropriate attachment type depending on the current XML element name.
override
elementAt(int index) → Attachment
Returns the indexth element.
inherited
every(bool test(Attachment element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Attachment element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(Attachment element), {Attachment orElse()?}) → Attachment
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Attachment element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Attachment> other) → Iterable<Attachment>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Attachment element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
GetCollectionItemXmlElementName(Attachment complexProperty) → String
Determines the name of the XML element associated with the complexProperty parameter.
override
HasUnprocessedChanges() → bool
Determines whether there are any unsaved attachment collection changes.
IndexOf(Attachment complexProperty) → int
Searches for a specific property and return its zero-based index within the collection.
inherited
InternalAdd(Attachment complexProperty, [bool loading = false]) → void
Add complex property.
inherited
InternalClear() → void
Clear collection.
inherited
InternalRemove(Attachment? complexProperty) → bool
Remove specified complex property.
inherited
InternalRemoveAt(int index) → void
Remote entry at index.
inherited
InternalValidate() → void
Validates this instance.
inherited
ItemChanged(ComplexProperty complexProperty) → void
Item changed.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(Attachment element), {Attachment orElse()?}) → Attachment
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? localElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? localElementName) → void
Loads from XML.
inherited
map<T>(T toElement(Attachment e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
OfType<T extends Attachment>() → List<T>
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
reduce(Attachment combine(Attachment value, Attachment element)) → Attachment
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
Remove(Attachment attachment) → bool
Removes the specified attachment.
RemoveAt(int index) → void
Removes the attachment at the specified index.
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
RemoveFromChangeLog(Attachment? complexProperty) → void
Removes from change log.
inherited
Save() → Future<void>
Saves this collection by creating new attachment and deleting removed ones.
ShouldWriteToRequest() → bool
Determine whether we should write collection to XML or not.
inherited
singleWhere(bool test(Attachment element), {Attachment orElse()?}) → Attachment
The single element that satisfies test.
inherited
skip(int count) → Iterable<Attachment>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Attachment element)) → Iterable<Attachment>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<Attachment>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Attachment element)) → Iterable<Attachment>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<Attachment>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<Attachment>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
inherited
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Validates this instance.
override
where(bool test(Attachment element)) → Iterable<Attachment>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → Attachment
Gets the property at the specified index.
inherited