ConversationId class

Represents the Id of a Conversation.
Inheritance

Constructors

ConversationId()
Initializes a new instance of the
ConversationId.fromUniqueId(String uniqueId)
Initializes a new instance of ConversationId.

Properties

ChangeKey ↔ String?
Gets the change key associated with the Exchange object. The change key represents the the version of the associated item or folder.
getter/setter pairinherited
hashCode → int
Serves as a hash function for a particular type.
no setterinherited
IsValid → bool
True if this instance is valid, false otherthise.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
UniqueId ↔ String?
Gets the unique Id of the Exchange object.
getter/setter pairinherited

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
Assign(ServiceId source) → void
Assigns from existing id.
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
GetXmlElementName() → String
Defines an implicit conversion between String and ConversationId.
override
InternalValidate() → void
Validates this instance.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
SameIdAndChangeKey(ServiceId other) → bool
Determines whether two ServiceId instances are equal (including ChangeKeys)
inherited
toString() → String
Gets a String representation of the Conversation Id.
override
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
inherited
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlElemenetName(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object obj) → bool
Determines whether the specified
inherited