EmailAddressCollection class

Represents a collection of e-mail addresses.
Inheritance

Constructors

EmailAddressCollection([String collectionItemXmlElementName = XmlElementNames.Mailbox])
Initializes a new instance of the

Properties

AddedItems → List<EmailAddress>
Gets the added items.
no setterinherited
collectionItemXmlElementName ↔ String?
XML element name
getter/setter pair
Count → int
Gets the total number of properties in the collection.
no setterinherited
first → EmailAddress
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
Items → List<EmailAddress>
Gets the items.
no setterinherited
iterator → Iterator<EmailAddress>
Gets an enumerator that iterates through the elements of the collection.
no setterinherited
last → EmailAddress
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
ModifiedItems → List<EmailAddress>
Gets the modified items.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
RemovedItems → List<EmailAddress?>
Gets the removed items.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → EmailAddress
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

Add(EmailAddress emailAddress) → void
Adds an e-mail address to the collection.
addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
AddRange(Iterable<EmailAddress> emailAddresses) → void
Adds multiple e-mail addresses to the collection.
AddRangeWithSmtpAddresses(Iterable<String> smtpAddresses) → void
Adds multiple e-mail addresses to the collection.
AddWithNameAndSmtpAddress(String name, String smtpAddress) → EmailAddress
Adds an e-mail address to the collection.
AddWithSmptpAddress(String smtpAddress) → EmailAddress
Adds an e-mail address to the collection.
any(bool test(EmailAddress element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
Changed() → dynamic
Instance was changed.
inherited
Clear() → void
Clears the collection.
ClearChangeLog() → void
Clears the change log.
inherited
Contains(EmailAddress complexProperty) → bool
Determines whether a specific property is in the collection.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
CreateComplexProperty(String xmlElementName) → EmailAddress?
Creates an EmailAddress object from an XML element name.
override
elementAt(int index) → EmailAddress
Returns the indexth element.
inherited
every(bool test(EmailAddress element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(EmailAddress element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(EmailAddress element), {EmailAddress orElse()?}) → EmailAddress
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, EmailAddress element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<EmailAddress> other) → Iterable<EmailAddress>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(EmailAddress emailAddress)) → void
Invokes action on each element of this iterable in iteration order.
inherited
GetCollectionItemXmlElementName(EmailAddress emailAddress) → String?
Retrieves the XML element name corresponding to the provided EmailAddress object.
override
IndexOf(EmailAddress complexProperty) → int
Searches for a specific property and return its zero-based index within the collection.
inherited
InternalAdd(EmailAddress complexProperty, [bool loading = false]) → void
Add complex property.
inherited
InternalClear() → void
Clear collection.
inherited
InternalRemove(EmailAddress? complexProperty) → bool
Remove specified complex property.
inherited
InternalRemoveAt(int index) → void
Remote entry at index.
inherited
InternalValidate() → void
Validates this instance.
inherited
ItemChanged(ComplexProperty complexProperty) → void
Item changed.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(EmailAddress element), {EmailAddress orElse()?}) → EmailAddress
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? localElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? localElementName) → void
Loads from XML.
inherited
map<T>(T toElement(EmailAddress e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
reduce(EmailAddress combine(EmailAddress value, EmailAddress element)) → EmailAddress
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
Remove(EmailAddress emailAddress) → bool
Removes an e-mail address from the collection.
RemoveAt(int index) → void
Removes an e-mail address from the collection.
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
RemoveFromChangeLog(EmailAddress? complexProperty) → void
Removes from change log.
inherited
ShouldWriteToRequest() → bool
Determine whether we should write collection to XML or not.
override
singleWhere(bool test(EmailAddress element), {EmailAddress orElse()?}) → EmailAddress
The single element that satisfies test.
inherited
skip(int count) → Iterable<EmailAddress>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(EmailAddress element)) → Iterable<EmailAddress>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<EmailAddress>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(EmailAddress element)) → Iterable<EmailAddress>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<EmailAddress>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<EmailAddress>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
inherited
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
where(bool test(EmailAddress element)) → Iterable<EmailAddress>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → EmailAddress
Gets the property at the specified index.
inherited