GroupMember class

Represents a group member.
Inheritance

Constructors

GroupMember()
Initializes a new instance of the

Properties

AddressInformation ↔ EmailAddress?
Gets the address information of the member.
getter/setter pair
addressInformation ↔ EmailAddress?
AddressInformation field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Key → String?
Initializes a new instance of the
no setter
key ↔ String?
Member key field.
getter/setter pair
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Status → MemberStatus?
Gets the status of the member.
no setter
status ↔ MemberStatus?
Status field.
getter/setter pair

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
AddressInformationChanged(ComplexProperty complexProperty) → void
AddressInformation instance is changed.
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
InternalValidate() → void
Validates this instance.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the member Key attribute from XML.
override
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
toString() → String
A string representation of this object.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read Status or Mailbox elements from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the member key attribute to XML.
override
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited