PhysicalAddressDictionary class

Represents a dictionary of physical addresses.
Inheritance

Constructors

PhysicalAddressDictionary()

Properties

Entries → Map<PhysicalAddressKey?, PhysicalAddressEntry>
Gets the entries.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
Contains(PhysicalAddressKey key) → bool
Determines whether this instance contains the specified key.
inherited
CreateEntry(EwsServiceXmlReader reader) → PhysicalAddressEntry?
Creates the entry.
inherited
CreateEntryInstance() → PhysicalAddressEntry
Creates instance of dictionary entry.
override
GetEntryXmlElementName(PhysicalAddressEntry? entry) → String
Gets the name of the entry XML element.
inherited
GetFieldIndex(PhysicalAddressKey? key) → String
Gets the index of the field.
inherited
GetFieldURI() → String?
Gets the field URI.
inherited
InternalAdd(PhysicalAddressEntry entry) → void
Add entry.
inherited
InternalAddOrReplace(PhysicalAddressEntry entry) → void
Add or replace entry.
inherited
InternalRemove(PhysicalAddressKey key) → void
Remove entry based on key.
inherited
InternalValidate() → void
Validates this instance.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? localElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
toString() → String
A string representation of this object.
inherited
TryGetValue(PhysicalAddressKey key, OutParam<PhysicalAddressEntry> physicalAddressOutParam) → bool
Tries to get the physical address associated with the specified key.
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
inherited
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteDeleteUpdateToXml(EwsServiceXmlWriter writer, ServiceObject? ewsObject) → bool
Writes deletion update to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
inherited
WriteSetUpdateToXml(EwsServiceXmlWriter writer, ServiceObject? ewsObject, PropertyDefinition propertyDefinition) → bool
Writes updates to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](PhysicalAddressKey key) → PhysicalAddressEntry?
Gets or sets the physical address at the specified key.
operator []=(PhysicalAddressKey key, PhysicalAddressEntry? value) → void