EndDateRecurrenceRange class

Represents recurrent range with an end date.
Inheritance

Constructors

EndDateRecurrenceRange()
Initializes a new instance of the
EndDateRecurrenceRange.withStartAndEndDates(DateTime? startDate, DateTime? endDate)
Initializes a new instance of the

Properties

EndDate ↔ DateTime?
Gets or sets the end date.
getter/setter pair
endDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
Recurrence ↔ Recurrence?
Gets or sets the recurrence.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
StartDate ↔ DateTime?
Gets or sets the start date.
getter/setter pairinherited
XmlElementName → String
Gets the name of the XML element.
no setteroverride

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → void
Changes handler.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
InternalValidate() → void
Validates this instance.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
SetupRecurrence(Recurrence recurrence) → void
Setups the recurrence.
override
toString() → String
A string representation of this object.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes the elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited