ReferenceAttachment class

Represents an attachment by reference.
Inheritance

Constructors

ReferenceAttachment.withOwner(Item owner)
Initializes a new instance of the

Properties

AttachmentIsFolder ↔ bool?
Gets or sets a value indicating whether the attachment points to a folder.
getter/setter pair
AttachmentLongPathName ↔ String?
Gets or sets a fully-qualified path identifying the attachment.
getter/setter pair
AttachmentPreviewUrl ↔ String?
Gets or sets the URL of the attachment preview.
getter/setter pair
AttachmentThumbnailUrl ↔ String?
Gets or sets the URL of the attachment thumbnail.
getter/setter pair
ContentId ↔ String?
Gets or sets the content Id of the attachment. ContentId can be used as a custom way to identify an attachment in order to reference it from within the body of the item the attachment belongs to.
getter/setter pairinherited
ContentLocation ↔ String?
Gets or sets the content location of the attachment. ContentLocation can be used to associate an attachment with a Url defining its location on the Web.
getter/setter pairinherited
ContentType ↔ String?
Gets or sets the content type of the attachment.
getter/setter pairinherited
DateTime ← DateTime
no getterinherited
hashCode → int
The hash code for this object.
no setterinherited
Id ↔ String?
Gets the Id of the attachment.
getter/setter pairinherited
IsInline ↔ bool?
Gets or sets a value indicating whether this is an inline attachment. Inline attachments are not visible to end users.
getter/setter pairinherited
IsNew → bool
True if the attachment has not yet been saved, false otherwise.
no setterinherited
LastModifiedTime → DateTime?
Gets the date and time when this attachment was last modified.
no setterinherited
Name ↔ String?
Gets or sets the name of the attachment.
getter/setter pairinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
Owner → Item?
Gets the owner of the attachment.
no setterinherited
PermissionType ↔ int?
Gets or sets the permission of the attachment.
getter/setter pair
ProviderEndpointUrl ↔ String?
Gets or sets the URL of the attachment provider.
getter/setter pair
ProviderType ↔ String?
Gets or sets the type of the attachment provider.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Gets the related exchange service.
no setterinherited
Size ↔ int?
Gets the size of the attachment.
getter/setter pairinherited

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
override
InternalLoad(BodyType? bodyType, Iterable<PropertyDefinitionBase>? additionalProperties) → Future<void>
Load the attachment.
inherited
InternalValidate() → void
Validates this instance.
inherited
Load() → Future<void>
Loads the attachment. Calling this method results in a call to EWS.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
ThrowIfThisIsNotNew() → void
Throws exception if this is not a new service object.
inherited
toString() → String
A string representation of this object.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
For ReferenceAttachment, the only thing need to patch is the AttachmentId.
override
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
ValidateWithIndex(int attachmentIndex) → void
Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements and content to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited