StringList class

Represents a list of strings.
Inheritance
Implemented types
Mixed-in types

Constructors

StringList()
Initializes a new instance of the
StringList.fromElementName(String itemXmlElementName)
Initializes a new instance of the
StringList.fromStrings(Iterable<String> strings)
Initializes a new instance of the

Properties

Count → int
Gets the number of strings in the list.
no setter
first → String
The first element.
no setterinherited
hashCode → int
Serves as a hash function for a particular type.
no setteroverride
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<String>
Gets an enumerator that iterates through the elements of the collection.
no setteroverride
last → String
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → String
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

Add(String s) → void
Adds a String to the list.
addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
AddRange(Iterable<String> strings) → void
Adds multiple strings to the list.
any(bool test(String element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
Changed() → dynamic
Instance was changed.
inherited
Clear() → void
Clears the list.
ClearChangeLog() → void
Clears the change log.
inherited
Contains(String s) → bool
Determines whether the list contains a specific string.
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → String
Returns the indexth element.
inherited
every(bool test(String element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(String element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(String element), {String orElse()?}) → String
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, String element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<String> other) → Iterable<String>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(String s)) → void
Invokes action on each element of this iterable in iteration order.
inherited
InternalValidate() → void
Validates this instance.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(String element), {String orElse()?}) → String
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
map<T>(T toElement(String e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
reduce(String combine(String value, String element)) → String
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
Remove(String s) → bool
Removes a String from the list.
RemoveAt(int index) → void
Removes the String at the specified position from the list.
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
singleWhere(bool test(String element), {String orElse()?}) → String
The single element that satisfies test.
inherited
skip(int count) → Iterable<String>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(String element)) → Iterable<String>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<String>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(String element)) → Iterable<String>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<String>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<String>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Generates a String representation of all the items in the list.
override
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
where(bool test(String element)) → Iterable<String>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object obj) → bool
Determines whether the specified
override
operator [](int index) → String?
Gets or sets the String at the specified index.
operator []=(int index, String value) → void