TimeChange class

Represents a change of time for a time zone.
Inheritance

Constructors

TimeChange()
Initializes a new instance of the
TimeChange.withOffset(TimeSpan offset)
Initializes a new instance of the
TimeChange.withOffsetAndTime(TimeSpan offset, Time time)
Initializes a new instance of the

Properties

AbsoluteDate ↔ DateTime?
Gets or sets the absolute date at which the change occurs. AbsoluteDate and Recurrence are mutually exclusive; setting one resets the other.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
Offset ↔ TimeSpan?
Gets or sets the offset since the beginning of the year when the change occurs.
getter/setter pair
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
Recurrence ↔ TimeChangeRecurrence?
Gets or sets the recurrence pattern defining when the change occurs. Recurrence and AbsoluteDate are mutually exclusive; setting one resets the other.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Time ↔ Time?
Gets or sets the time at which the change occurs.
getter/setter pair
TimeZoneName ↔ String?
Gets or sets the name of the associated time zone.
getter/setter pair

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
InternalValidate() → void
Validates this instance.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
override
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
toString() → String
A string representation of this object.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited