TimeZoneTransition class

Represents the base class for all time zone transitions.
Inheritance
Implementers

Constructors

TimeZoneTransition(TimeZoneDefinition? timeZoneDefinition)
Initializes a new instance of the
TimeZoneTransition.withTimeZonePeriod(TimeZoneDefinition timeZoneDefinition, TimeZonePeriod targetPeriod)
Initializes a new instance of the
TimeZoneTransition.withTimeZoneTransitionGroup(TimeZoneDefinition timeZoneDefinition, TimeZoneTransitionGroup targetGroup)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TargetGroup → TimeZoneTransitionGroup?
Gets the target transition group of the transition.
no setter
targetGroup ↔ TimeZoneTransitionGroup?
getter/setter pair
TargetPeriod → TimeZonePeriod?
Gets the target period of the transition.
no setter
targetPeriod ↔ TimeZonePeriod?
getter/setter pair
timeZoneDefinition ↔ TimeZoneDefinition?
getter/setter pair

Methods

addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
Changed() → dynamic
Instance was changed.
inherited
ClearChangeLog() → void
Clears the change log.
inherited
GetXmlElementName() → String
Gets the XML element name associated with the transition.
InternalValidate() → void
Validates this instance.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlElementName(EwsServiceXmlReader reader) → void
Loads from XML.
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
toString() → String
A string representation of this object.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlElementName(EwsServiceXmlWriter writer) → void
Writes to XML.
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Create(TimeZoneDefinition? timeZoneDefinition, String xmlElementName) → TimeZoneTransition
Creates a time zone period transition of the appropriate type given an XML element name.

Constants

GroupTarget → const String
PeriodTarget → const String