EwsServiceMultiResponseXmlReader class

//

Inheritance

Properties

HasAttributes → bool
Gets a value indicating whether this instance has attributes.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
IsEmptyElement → bool
Gets a value indicating whether current element is empty.
no setterinherited
LocalName → String
Gets the local name of the current element.
no setterinherited
NamespacePrefix → String
Gets the namespace prefix.
no setterinherited
NamespaceUri → String
Gets the namespace URI.
no setterinherited
NodeType → XmlNodeType?
Gets the type of the node.
no setterinherited
PrevNodeType → XmlNodeType?
Gets the type of the prev node.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Gets the service.
no setterinherited

Methods

EnsureCurrentNodeIsEndElement(XmlNamespace xmlNamespace, String localName) → void
Ensures the current node is end element.
inherited
EnsureCurrentNodeIsStartElement() → void
Ensures the current node is start element.
inherited
EnsureCurrentNodeIsStartElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → void
Ensures the current node is start element.
inherited
GetXmlReaderForNode() → XmlReader
Gets the XML reader for node.
inherited
InternalReadElementWithNamespace(XmlNamespace xmlNamespace, String? localName, XmlNodeType nodeType) → Future<void>
Read XML element.
inherited
IsEndElement(String namespacePrefix, String localName) → bool
Determines whether current element is a end element.
inherited
IsEndElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → bool
Determines whether current element is a end element.
inherited
IsStartElement() → bool
Determines whether current element is a start element.
inherited
IsStartElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → bool
Determines whether current element is a start element.
inherited
IsStartElementWithPrefix(String namespacePrefix, String localName) → bool
Determines whether current element is a start element.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Read({XmlNodeType? nodeType = null}) → Future<void>
Reads the next node.
inherited
ReadAttributeStringValue(String attributeName) → String?
Reads the attribute value.
inherited
ReadAttributeValue<T>(String attributeName) → T?
Reads the attribute value.
inherited
ReadAttributeValueWithNamespace(XmlNamespace xmlNamespace, String attributeName) → String?
Reads the attribute value.
inherited
ReadBase64ElementValue() → Future<Uint8List>
Reads the base64 element value.
inherited
ReadBase64ElementValueWithStream(Stream? outputStream) → void
Reads the base64 element value.
inherited
ReadElementStringValue() → Future<String?>
Reads the element value.
inherited
ReadElementStringValueWithNamespace(XmlNamespace xmlNamespace, String localName) → Future<String?>
Reads the element value.
inherited
ReadElementStringValueWithPrefix(String namespacePrefix, String localName) → Future<String?>
Reads the element value.
inherited
ReadElementValue<T>() → Future<T?>
Reads the element value.
inherited
ReadElementValueAsDateTime() → Future<DateTime?>
Reads the element value as date time.
inherited
ReadElementValueAsUnspecifiedDate() → Future<DateTime?>
Reads the element value as unspecified date.
inherited
ReadElementValueWithNamespace<T>(XmlNamespace xmlNamespace, String? localName) → Future<T?>
Reads the element value.
inherited
ReadEndElementIfNecessary(XmlNamespace xmlNamespace, String? localName) → Future<void>
Reads the end element if necessary.
inherited
ReadEndElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → Future<void>
Reads the end element.
inherited
ReadEndElementWithPrefix(String namespacePrefix, String elementName) → Future<void>
Reads the end element.
inherited
ReadInnerXml() → String
Reads the Inner XML at the given location.
inherited
ReadNullableAttributeValue<T>(String attributeName) → T?
Reads a nullable attribute value.
inherited
ReadOuterXml() → String
Reads the Outer XML at the given location.
inherited
ReadServiceObjectsCollectionFromXml<TServiceObject extends ServiceObject>(String collectionXmlElementName, IGetObjectInstanceDelegate<TServiceObject> getObjectInstanceDelegate, bool clearPropertyBag, PropertySet? requestedPropertySet, bool summaryPropertiesOnly) → Future<List<TServiceObject>>
Reads the service objects collection from XML.
inherited
ReadServiceObjectsCollectionFromXmlWithNamespace<TServiceObject extends ServiceObject>(XmlNamespace collectionXmlNamespace, String collectionXmlElementName, IGetObjectInstanceDelegate<TServiceObject> getObjectInstanceDelegate, bool clearPropertyBag, PropertySet? requestedPropertySet, bool summaryPropertiesOnly) → Future<List<TServiceObject>>
Reads the element value as date time, assuming it is unbiased (e.g. 2009/01/01T08:00) and scoped to service's time zone.
inherited
ReadStartElement(String namespacePrefix, String localName) → Future<void>
Reads the start element.
inherited
ReadStartElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → Future<void>
Reads the start element.
inherited
ReadStringValue() → Future<String>
Reads the value.
inherited
ReadToDescendant(XmlNamespace xmlNamespace, String localName) → void
Reads to the next descendant element with the specified local name and namespace.
inherited
ReadValue<T>() → Future<T?>
Reads the value.
inherited
SkipCurrentElement() → Future<void>
Skips the current element.
inherited
SkipElement(String namespacePrefix, String localName) → Future<void>
Skips the element.
inherited
SkipElementWithNamspace(XmlNamespace xmlNamespace, String localName) → Future<void>
Skips the element.
inherited
toString() → String
A string representation of this object.
inherited
TryReadValue(OutParam<String> value) → Future<bool>
Tries to read value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Create(Stream<List<int>> stream, ExchangeService service) → Future<EwsServiceMultiResponseXmlReader>
override