EwsUtilities class

EWS utilities

Constructors

EwsUtilities()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

enumToSchemaDictionaries ↔ LazyMember<Map<Type, Map<Object, String?>>>
Dictionary of enum type to enum-value-to-schema-name maps.
getter/setter pair
enumVersionDictionaries ↔ LazyMember<Map<Type, Map<dynamic, ExchangeVersion?>>>
Dictionary of enum type to ExchangeVersion maps.
getter/setter pair
PATTERN_DAY → RegExp
final
PATTERN_HOUR → RegExp
final
PATTERN_MILLISECONDS → RegExp
final
PATTERN_MINUTES → RegExp
final
PATTERN_MONTH → RegExp
final
PATTERN_SECONDS → RegExp
final
PATTERN_TIME_SPAN → RegExp
final
PATTERN_YEAR → RegExp
final
possibleEnumsConverter ↔ Map<Type, Converter<String, Object?>>
getter/setter pair
schemaToEnumDictionaries ↔ LazyMember<Map<Type, Map<String, dynamic>>>
Dictionary of enum type to schema-name-to-enum-value maps.
getter/setter pair
serializedEnumDictionaries → List<Type>
final
serviceObjectInfo ↔ LazyMember<ServiceObjectInfo>
Map from XML element names to ServiceObject type and constructors.
getter/setter pair

Static Methods

Assert(bool condition, String caller, String message) → void
Asserts that the specified condition if true.
BoolToXSBool(bool value) → String
Convert bool to XML Schema bool.
BuildSchemaToEnumDict(Type enumType) → Map<String, Object>
Builds the schema to enum mapping dictionary.BuildSchemaToEnumDict
ConvertTime(DateTime dateTime, TimeZone sourceTimeZone, TimeZone destinationTimeZone) → DateTime
Converts the specified date and time from one time zone to another.
CopyStream(Stream<List<int>> source, StreamConsumer<List<int>> target) → Future<void>
Copies source stream to target.
CreateEwsObjectFromXmlElementName<TServiceObject extends ServiceObject>(ExchangeService? service, String xmlElementName) → TServiceObject
Creates EWS object based on XML element name.
CreateItemFromItemClass(ItemAttachment itemAttachment, Type? itemClass, bool isNew) → Item
Creates Item from Item class.
CreateItemFromXmlElementName(ItemAttachment itemAttachment, String xmlElementName) → Item?
Creates Item based on XML element name.
DateTimeToXSDate(DateTime date) → String
Convert DateTime to XML Schema date.
DateTimeToXSDateTime(DateTime dateTime) → String
Dates the DateTime into an XML schema date time.
DomainFromEmailAddress(String emailAddress) → String
Gets the domain name from an email address.
FindFirstItemOfType<TItem extends Item>(Iterable<Item> items) → TItem?
Finds the first item of type TItem (not a descendant type) in the specified collection.
FormatHttpHeaders(WebHeaderCollection headers) → String
Formats HTTP headers.
FormatHttpHeadersWithBuffer(StringBuffer sb, WebHeaderCollection headers) → void
FormatHttpRequestHeaders(IEwsHttpWebRequest request) → String
Format request HTTP headers.
FormatHttpResponseHeaders(IEwsHttpWebResponse response) → String
Format response HTTP headers.
FormatLogMessage(String entryKind, String logEntry) → String
Format log message.
FormatLogMessageWithXmlContent(String entryKind, MemoryStream memoryStream) → String
Format XML content in a MemoryStream for message.
GetEnumeratedObjectAt(Iterable objects, int index) → Object
Gets enumerated object at index.
GetEnumeratedObjectCount(Iterable objects) → int
Gets the enumerated object count.
GetEnumSchemaName(Type enumType, Object enumValue) → String?
Gets the schema name for enum member.
GetEnumVersion(Type enumType, dynamic enumValue) → ExchangeVersion?
Gets version for enum member.
GetItemTypeFromXmlElementName(String xmlElementName) → Type?
Gets the expected item type based on the local name.
GetNamespaceFromUri(String namespaceUri) → XmlNamespace
Gets the XmlNamespace enum value from a namespace Uri.
GetNamespacePrefix(XmlNamespace xmlNamespace) → String
Gets the namespace prefix from an XmlNamespace enum value.
GetNamespaceUri(XmlNamespace xmlNamespace) → String
Gets the namespace URI from an XmlNamespace enum value.
Parse<T>(String? value) → T?
Parses specified value based on type.
TimeSpanToXSDuration(TimeSpan timeSpan) → String
Takes a System.TimeSpan structure and converts it into an xs:duration String as defined by the W3 Consortiums Recommendation "XML Schema Part 2: Datatypes Second Edition", http://www.w3.org/TR/xmlschema-2/#duration
TryParse<T>(String? value, OutParam<T> resultOutParam) → bool
Tries to parses the specified value to the specified type.
TrySerializeEnum(Object enumValue, OutParam<String> resultOutParam) → bool
ValidateClassVersion(ExchangeService service, ExchangeVersion minimumServerVersion, String className) → void
Validates class version against the request version.
ValidateDomainNameAllowNull(String? domainName, String paramName) → void
Validates domain name (null value allowed)
ValidateEnumVersionValue(dynamic enumValue, ExchangeVersion requestVersion) → void
Validates the enum value against the request version.
ValidateMethodVersion(ExchangeService service, ExchangeVersion minimumServerVersion, String methodName) → void
Validates method version against the request version.
ValidateNonBlankStringParam(String? param, String paramName) → void
Validates String parameter to be non-empty String (null value not allowed).
ValidateNonBlankStringParamAllowNull(String? param, String paramName) → void
Validates string parameter to be non-empty string (null value allowed).
ValidateParam(Object? param, String paramName) → void
Validates parameter (null value not allowed).
ValidateParamAllowNull(Object? param, String paramName) → void
Validates parameter (and allows null value).
ValidateParamCollection(Iterable collection, String paramName) → void
Validates parameter collection.
ValidatePropertyVersion(ExchangeService service, ExchangeVersion minimumServerVersion, String propertyName) → void
Validates parameter collection.
ValidateServiceObjectVersion(ServiceObject serviceObject, ExchangeVersion requestVersion) → void
Validates service object version against the request version.
WriteTraceStartElement(XmlWriter writer, String traceTag, bool includeVersion) → void
Write trace start element.
XSDurationToTimeSpan(String xsDuration) → TimeSpan
Takes an xs:duration String as defined by the W3 Consortiums Recommendation "XML Schema Part 2: Datatypes Second Edition", http://www.w3.org/TR/xmlschema-2/#duration, and converts it into a System.TimeSpan structure