EwsXmlReader class

XML reader.
Implementers

Constructors

EwsXmlReader(XmlReader _xmlReader)
Initializes a new instance of the

Properties

HasAttributes → bool
Gets a value indicating whether this instance has attributes.
no setter
hashCode → int
The hash code for this object.
no setterinherited
IsEmptyElement → bool
Gets a value indicating whether current element is empty.
no setter
LocalName → String
Gets the local name of the current element.
no setter
NamespacePrefix → String
Gets the namespace prefix.
no setter
NamespaceUri → String
Gets the namespace URI.
no setter
NodeType → XmlNodeType?
Gets the type of the node.
no setter
PrevNodeType → XmlNodeType?
Gets the type of the prev node.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

EnsureCurrentNodeIsEndElement(XmlNamespace xmlNamespace, String localName) → void
Ensures the current node is end element.
EnsureCurrentNodeIsStartElement() → void
Ensures the current node is start element.
EnsureCurrentNodeIsStartElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → void
Ensures the current node is start element.
GetXmlReaderForNode() → XmlReader
Gets the XML reader for node.
InternalReadElementWithNamespace(XmlNamespace xmlNamespace, String? localName, XmlNodeType nodeType) → void
Read XML element.
IsEndElement(String namespacePrefix, String localName) → bool
Determines whether current element is a end element.
IsEndElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → bool
Determines whether current element is a end element.
IsStartElement() → bool
Determines whether current element is a start element.
IsStartElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → bool
Determines whether current element is a start element.
IsStartElementWithPrefix(String namespacePrefix, String localName) → bool
Determines whether current element is a start element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Read({XmlNodeType? nodeType = null}) → void
Reads the next node.
ReadAttributeStringValue(String attributeName) → String?
Reads the attribute value.
ReadAttributeValue<T>(String attributeName) → T?
Reads the attribute value.
ReadAttributeValueWithNamespace(XmlNamespace xmlNamespace, String attributeName) → String?
Reads the attribute value.
ReadBase64ElementValue() → Uint8List
Reads the base64 element value.
ReadBase64ElementValueWithStream(Stream? outputStream) → void
Reads the base64 element value.
ReadElementStringValue() → String?
Reads the element value.
ReadElementStringValueWithNamespace(XmlNamespace xmlNamespace, String localName) → String?
Reads the element value.
ReadElementStringValueWithPrefix(String namespacePrefix, String localName) → String?
Reads the element value.
ReadElementValue<T>() → T?
Reads the element value.
ReadElementValueWithNamespace<T>(XmlNamespace xmlNamespace, String? localName) → T?
Reads the element value.
ReadEndElementIfNecessary(XmlNamespace xmlNamespace, String? localName) → void
Reads the end element if necessary.
ReadEndElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → void
Reads the end element.
ReadEndElementWithPrefix(String namespacePrefix, String elementName) → void
Reads the end element.
ReadInnerXml() → String
Reads the Inner XML at the given location.
ReadNullableAttributeValue<T>(String attributeName) → T?
Reads a nullable attribute value.
ReadOuterXml() → String
Reads the Outer XML at the given location.
ReadStartElement(String namespacePrefix, String localName) → void
Reads the start element.
ReadStartElementWithNamespace(XmlNamespace xmlNamespace, String? localName) → void
Reads the start element.
ReadStringValue() → String
Reads the value.
ReadToDescendant(XmlNamespace xmlNamespace, String localName) → void
Reads to the next descendant element with the specified local name and namespace.
ReadValue<T>() → T?
Reads the value.
SkipCurrentElement() → void
Skips the current element.
SkipElement(String namespacePrefix, String localName) → void
Skips the element.
SkipElementWithNamspace(XmlNamespace xmlNamespace, String localName) → void
Skips the element.
toString() → String
A string representation of this object.
inherited
TryReadValue(OutParam<String> value) → bool
Tries to read value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

FormatElementName(String namespacePrefix, String localElementName) → String
Formats the name of the element.
InitializeXmlReader(Stream stream) → Future<XmlReader>
Initializes the XML reader.