ExchangeServerInfo class

Represents Exchange server information.

Constructors

ExchangeServerInfo()
Default constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
MajorBuildNumber ↔ int?
Gets the Major Exchange server build number
getter/setter pair
MajorVersion ↔ int?
Gets the Major Exchange server version number
getter/setter pair
MinorBuildNumber ↔ int?
Gets the Minor Exchange server build number
getter/setter pair
MinorVersion ↔ int?
Gets the Minor Exchange server version number
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
VersionString ↔ String?
Gets the Exchange server version String (e.g. "Exchange2010")
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Override toString() method
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Parse(EwsServiceXmlReader reader) → ExchangeServerInfo
Parse current element to extract server information