ServiceRequestBase class abstract

Represents an service request.
Implementers

Constructors

ServiceRequestBase(ExchangeService _service)
Initializes a new instance of the

Properties

AnchorMailbox ↔ String?
Gets or sets the anchor mailbox associated with the request
getter/setter pair
EmitTimeZoneHeader → bool
Gets a value indicating whether the TimeZoneContext SOAP header should be eimitted.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Gets the service.
no setter

Methods

AddHeaders(WebHeaderCollection? webHeaderCollection) → void
Allows the subclasses to add their own header information
BuildEwsHttpWebRequest() → Future<IEwsHttpWebRequest>
Builds the IEwsHttpWebRequest object for current service request with exception handling.
GetEwsHttpWebResponse(IEwsHttpWebRequest request) → Future<IEwsHttpWebResponse>
Gets the IEwsHttpWebRequest object from the specified IEwsHttpWebRequest object with exception handling
GetMinimumRequiredServerVersion() → ExchangeVersion
Gets the minimum server version required to process this request.
GetResponseXmlElementName() → String
Gets the name of the response XML element.
GetXmlElementName() → String
Gets the name of the XML element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ParseResponse(EwsServiceXmlReader reader) → Object
Parses the response.
ParseResponseWithHeaders(EwsServiceXmlReader reader, WebHeaderCollection responseHeaders) → Object
Parses the response.
ReadPreamble(EwsServiceXmlReader ewsXmlReader) → void
Reads any preamble data not part of the core response.
ReadResponseWithHeaders(EwsServiceXmlReader ewsXmlReader, WebHeaderCollection? responseHeaders) → Object
Reads the response.
ReadSoapFault(EwsServiceXmlReader reader) → SoapFaultDetails?
Reads the SOAP fault.
ThrowIfNotSupportedByRequestedServerVersion() → void
Throw exception if request is not supported in requested server version.
toString() → String
A string representation of this object.
inherited
TraceResponseXml(IEwsHttpWebResponse response, MemoryStream memoryStream) → void
Traces the response. This should only be used for synchronous requests, or synchronous situations (such as a WebException on an asynchrounous request).
TraceXmlRequest(MemoryStream memoryStream) → void
Traces an XML request. This should only be used for synchronous requests, or synchronous situations (such as a WebException on an asynchrounous request).
Validate() → void
Validate request.
ValidateAndEmitRequest() → Future<IEwsHttpWebResponse>
Validates request parameters, and emits the request to the server.
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes XML attributes.
WriteBodyToXml(EwsServiceXmlWriter writer) → void
Writes XML body.
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes XML elements.
WriteToXml(EwsServiceXmlWriter writer) → void
Writes XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

GetResponseStream(IEwsHttpWebResponse response) → Stream
Gets the response stream (may be wrapped with GZip/Deflate stream to decompress content)
GetResponseStreamWithTimeout(IEwsHttpWebResponse response, int readTimeout) → Stream<List<int>>
Gets the response stream (may be wrapped with GZip/Deflate stream to decompress content)