UnsubscribeRequest class

Represents an Unsubscribe request.
Inheritance

Constructors

UnsubscribeRequest(ExchangeService service)
Initializes a new instance of the

Properties

AnchorMailbox ↔ String?
Gets or sets the anchor mailbox associated with the request
getter/setter pairinherited
EmitTimeZoneHeader → bool
Gets a value indicating whether the TimeZoneContext SOAP header should be eimitted.
no setterinherited
ErrorHandlingMode → ServiceErrorHandling?
Ends executing this async request.
no setterinherited
errorHandlingMode ↔ ServiceErrorHandling?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Gets the service.
no setterinherited
SubscriptionId ↔ String?
Gets or sets the subscription id.
getter/setter pair

Methods

AddHeaders(WebHeaderCollection? webHeaderCollection) → void
Allows the subclasses to add their own header information
inherited
BuildEwsHttpWebRequest() → Future<IEwsHttpWebRequest>
Builds the IEwsHttpWebRequest object for current service request with exception handling.
inherited
CreateServiceResponse(ExchangeService service, int responseIndex) → ServiceResponse
Creates service response.
override
Execute() → Future<ServiceResponseCollection<ServiceResponse>>
Executes this request.
inherited
GetEwsHttpWebResponse(IEwsHttpWebRequest request) → Future<IEwsHttpWebResponse>
Gets the IEwsHttpWebRequest object from the specified IEwsHttpWebRequest object with exception handling
inherited
GetExpectedResponseMessageCount() → int
Gets the expected response message count.
override
GetMinimumRequiredServerVersion() → ExchangeVersion
Gets the request version.
override
GetResponseMessageXmlElementName() → String
Gets the name of the response message XML element.
override
GetResponseXmlElementName() → String
Gets the name of the response XML element.
override
GetXmlElementName() → String
Gets the name of the XML element.
override
InternalExecute() → Future<Object>
Executes this request.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ParseResponse(EwsServiceXmlReader reader) → Object
Parses the response.
inherited
ParseResponseWithHeaders(EwsServiceXmlReader reader, WebHeaderCollection responseHeaders) → Object
Parses the response.
inherited
ReadPreamble(EwsServiceXmlReader ewsXmlReader) → void
Reads any preamble data not part of the core response.
inherited
ReadResponseWithHeaders(EwsServiceXmlReader ewsXmlReader, WebHeaderCollection? responseHeaders) → Object
Reads the response.
inherited
ReadSoapFault(EwsServiceXmlReader reader) → SoapFaultDetails?
Reads the SOAP fault.
inherited
ThrowIfNotSupportedByRequestedServerVersion() → void
Throw exception if request is not supported in requested server version.
inherited
toString() → String
A string representation of this object.
inherited
TraceResponseXml(IEwsHttpWebResponse response, MemoryStream memoryStream) → void
Traces the response. This should only be used for synchronous requests, or synchronous situations (such as a WebException on an asynchrounous request).
inherited
TraceXmlRequest(MemoryStream memoryStream) → void
Traces an XML request. This should only be used for synchronous requests, or synchronous situations (such as a WebException on an asynchrounous request).
inherited
Validate() → void
Validate the request.
override
ValidateAndEmitRequest() → Future<IEwsHttpWebResponse>
Validates request parameters, and emits the request to the server.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes XML attributes.
inherited
WriteBodyToXml(EwsServiceXmlWriter writer) → void
Writes XML body.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes XML elements.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited