SearchFolder class

Represents a search folder.
Inheritance

Constructors

SearchFolder(ExchangeService service)
Initializes an unsaved local instance of

Properties

ChildFolderCount → int?
Gets the number of child folders this folder has.
no setterinherited
DisplayName ↔ String?
Gets or sets the display name of the folder.
getter/setter pairinherited
EffectiveRights → EffectiveRights?
Gets the Email Lifecycle Management (ELC) information associated with the folder.
no setterinherited
ExtendedProperties → ExtendedPropertyCollection
Gets a list of extended properties associated with the folder.
no setterinherited
FolderClass ↔ String?
Gets or sets the custom class name of this folder.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
Id → FolderId?
Gets the Id of the folder.
no setterinherited
IsDirty → bool
Gets a value indicating whether the object has been modified and should be saved.
no setterinherited
IsNew → bool
Indicates whether this object is a real store item, or if it's a local object that has yet to be saved.
no setterinherited
onChange ↔ List<IServiceObjectChangedDelegate>
Defines an event that is triggered when the service object changes.
getter/setter pairinherited
ParentFolderId → FolderId?
Gets the Id of this folder's parent folder.
no setterinherited
Permissions → FolderPermissionCollection
Gets a list of permissions for the folder.
no setterinherited
PropertyBag → PropertyBag
The property bag holding property values for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Schema → ServiceObjectSchema
Gets the schema associated with this type of object.
no setterinherited
SearchParameters → SearchFolderParameters
Gets the search parameters associated with the search folder.
no setter
Service ↔ ExchangeService
Gets the ExchangeService the object is bound to.
getter/setter pairinherited
TotalCount → int?
Gets the total number of items contained in the folder.
no setterinherited
UnreadCount → int?
Gets the number of unread items in the folder.
no setterinherited
WellKnownFolderName → WellKnownFolderName?
Gets the well known name of this folder, if any.
no setterinherited
WellKnownFolderNameAsString → String?
Gets or sets the policy tag.
no setterinherited

Methods

Changed() → void
Triggers dispatch of the change event.
inherited
ClearChangeLog() → void
Clears the object's change log.
inherited
Delete(DeleteMode deleteMode) → Future<void>
Deletes the folder. Calling this method results in a call to EWS.
inherited
FindItems(SearchFilter searchFilter, ItemView view) → Future<FindItemsResults<Item>?>
Obtains a list of items by searching the contents of this folder. Calling this method results in a call to EWS.
inherited
GetChangeXmlElementName() → String
Gets the name of the change XML element.
inherited
GetDeleteFieldXmlElementName() → String
Gets the name of the delete field XML element.
inherited
GetExtendedProperties() → ExtendedPropertyCollection?
Gets a list of extended properties defined on this object.
inherited
GetId() → ServiceId?
The unique Id of this object.
inherited
GetIdPropertyDefinition() → PropertyDefinition
Obtains a list of items by searching the contents of this folder. Calling this method results in a call to EWS.
inherited
GetIsCustomDateTimeScopingRequired() → bool
Determines whether properties defined with ScopedDateTimePropertyDefinition require custom time zone scoping.
inherited
GetIsTimeZoneHeaderRequired(bool isUpdateOperation) → bool
Gets a value indicating whether a time zone SOAP header should be emitted in a CreateItem or UpdateItem request so this item can be property saved or updated.
inherited
GetLoadedPropertyDefinitions() → List<PropertyDefinitionBase?>
Gets the collection of loaded property definitions.
inherited
GetMinimumRequiredServerVersion() → ExchangeVersion
Gets the minimum required server version.
override
GetSchema() → ServiceObjectSchema
method to return the schema associated with this type of object.
override
getServiceObjectDefinitionAttribute() → ServiceObjectDefinitionAttribute
override
GetSetFieldXmlElementName() → String
Gets the name of the set field XML element.
inherited
GetXmlElementName() → String?
GetXmlElementName retrieves the XmlElementName of this type based on the EwsObjectDefinition attribute that decorates it, if present.
inherited
GetXmlElementNameOverride() → String?
This methods lets subclasses of ServiceObject override the default mechanism by which the XML element name associated with their type is retrieved.
inherited
InternalDelete(DeleteMode deleteMode, SendCancellationsMode? sendCancellationsMode, AffectedTaskOccurrence? affectedTaskOccurrences) → Future<void>
Deletes the object.
inherited
InternalFindItems<TItem extends Item>(String? queryString, ViewBase view, Grouping? groupBy) → Future<ServiceResponseCollection<FindItemResponse<TItem>>>
Copies this folder into a specific folder. Calling this method results in a call to EWS.
inherited
InternalFindItemsGeneric<TItem extends Item>(SearchFilter searchFilter, ViewBase view, Grouping? groupBy) → Future<ServiceResponseCollection<FindItemResponse<TItem>>>
Find items.
inherited
InternalLoad(PropertySet propertySet) → Future<void>
Loads the specified set of properties on the object.
inherited
Load() → Future<void>
Loads the first class properties. Calling this method results in a call to EWS.
inherited
LoadFromXml(EwsServiceXmlReader reader, bool clearPropertyBag) → void
Loads service object from XML.
inherited
LoadFromXmlWithPropertySet(EwsServiceXmlReader reader, bool clearPropertyBag, PropertySet? requestedPropertySet, bool summaryPropertiesOnly) → void
Loads service object from XML.
inherited
LoadWithPropertySet(PropertySet propertySet) → Future<void>
Loads the specified set of properties. Calling this method results in a call to EWS.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
RemoveExtendedProperty(ExtendedPropertyDefinition extendedPropertyDefinition) → bool
Removes an extended property.
inherited
Save(FolderId parentFolderId) → Future<void>
Empties the folder. Calling this method results in a call to EWS.
inherited
SaveWithWellKnownFolderName(WellKnownFolderName parentFolderName) → Future<void>
Saves this folder in a specific folder. Calling this method results in a call to EWS.
inherited
SetExtendedProperty(ExtendedPropertyDefinition extendedPropertyDefinition, Object value) → void
Sets the extended property.
inherited
ThrowIfThisIsNew() → void
Throws exception if this is a new service object.
inherited
ThrowIfThisIsNotNew() → void
Throws exception if this is not a new service object.
inherited
toString() → String
A string representation of this object.
inherited
TryGetExtendedProperty<T>(ExtendedPropertyDefinition propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified extended property in this instance.
inherited
TryGetProperty(PropertyDefinitionBase propertyDefinition, OutParam<Object> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
inherited
TryGetPropertyGeneric<T>(PropertyDefinitionBase propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
inherited
Update() → Future<void>
Applies the local changes that have been made to this folder. Calling this method results in a call to EWS.
inherited
Validate() → void
Validates this instance.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes service object as XML.
inherited
WriteToXmlForUpdate(EwsServiceXmlWriter writer) → void
Writes service object for update as XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](PropertyDefinitionBase propertyDefinition) → Object?
Gets the value of specified property in this instance.
inherited

Static Methods

BindWithFolderId(ExchangeService service, FolderId id) → Future<SearchFolder>
Binds to an existing search folder and loads its first class properties. Calling this method results in a call to EWS.
BindWithFolderIdAndPropertySet(ExchangeService service, FolderId id, PropertySet propertySet) → Future<SearchFolder>
Binds to an existing search folder and loads the specified set of properties. Calling this method results in a call to EWS.
BindWithWellKnownFolder(ExchangeService service, WellKnownFolderName name) → Future<SearchFolder>
Binds to an existing search folder and loads its first class properties. Calling this method results in a call to EWS.
override
BindWithWellKnownFolderAndPropertySet(ExchangeService service, WellKnownFolderName name, PropertySet propertySet) → Future<SearchFolder>
Binds to an existing search folder and loads the specified set of properties. Calling this method results in a call to EWS.