Item class

Represents a generic item. Properties available on items are defined in the ItemSchema class.
Inheritance
Implementers

Constructors

Item(ExchangeService service)
Initializes an unsaved local instance of
Item.withAttachment(ItemAttachment parentAttachment)
Initializes a new instance of the

Properties

Attachments → AttachmentCollection
Gets a list of the attachments to this item.
no setter
Body ↔ MessageBody?
Gets or sets the body of this item.
getter/setter pair
Categories ↔ StringList
Gets or sets the list of categories associated with this item.
getter/setter pair
DateTimeCreated → DateTime?
Gets the date and time this item was created.
no setter
DateTimeReceived → DateTime?
Gets the time when this item was received.
no setter
DateTimeSent → DateTime?
Gets a list of Internet headers for this item.
no setter
DefaultAffectedTaskOccurrences → AffectedTaskOccurrence?
Gets the icon index.
no setter
DefaultSendCancellationsMode → SendCancellationsMode?
Gets the default setting for sending cancellations on Delete. Subclasses will override this for different default behavior.
no setter
DefaultSendInvitationsMode → SendInvitationsMode?
Gets the default settings for sending invitations on Save. Subclasses will override this for different default behavior.
no setter
DefaultSendInvitationsOrCancellationsMode → SendInvitationsOrCancellationsMode?
Gets the default settings for sending invitations or cancellations on Update. Subclasses will override this for different default behavior.
no setter
EffectiveRights → Set<EffectiveRights>?
Gets a value indicating the effective rights the current authenticated user has on this item.
no setter
ExtendedProperties → ExtendedPropertyCollection
Gets a list of extended properties defined on this item.
no setter
HasAttachments → bool?
Gets or sets the number of minutes before the start of this item when the reminder should be triggered.
no setter
hashCode → int
The hash code for this object.
no setterinherited
ICalUid → String?
no setter
Id → ItemId?
Gets the Id of this item.
no setter
Importance ↔ Importance?
Gets or sets the culture associated with this item.
getter/setter pair
InstanceKey → Uint8List?
Gets the item instance key.
no setter
IsAssociated → bool?
Gets a value indicating whether this is an associated item.
no setter
IsAttachment → bool
Gets a value indicating whether the item is an attachment.
no setter
IsDirty → bool
Gets a value indicating whether the object has been modified and should be saved.
no setterinherited
IsDraft → bool?
Gets a value indicating whether the item is is a draft. An item is a draft when it has not yet been sent.
no setter
IsFromMe → bool?
Gets a value indicating whether the item has been sent by the current authenticated user.
no setter
IsNew → bool
Gets a value indicating whether this object is a real store item, or if it's a local object that has yet to be saved.
no setteroverride
IsReminderSet ↔ bool?
Gets or sets a value indicating whether a reminder is set for this item.
getter/setter pair
IsResend → bool?
Gets a value indicating whether the item is a resend of another item.
no setter
IsSubmitted → bool?
Gets or sets the In-Reply-To reference of this item.
no setter
IsUnmodified → bool?
Gets a value indicating whether the item has been modified since it was created.
no setter
ItemClass ↔ String?
Gets or sets the custom class name of this item.
getter/setter pair
LastModifiedName → String?
Gets the name of the user who last modified this item.
no setter
LastModifiedTime → DateTime?
Gets the date and time this item was last modified.
no setter
MimeContent ↔ MimeContent?
Get or sets the MIME content of this item.
getter/setter pair
onChange ↔ List<IServiceObjectChangedDelegate>
Defines an event that is triggered when the service object changes.
getter/setter pairinherited
ParentAttachment → ItemAttachment?
Gets the parent attachment of this item.
no setter
ParentFolderId → FolderId?
Get or sets the MimeContentUTF8 of this item.
no setter
Preview → String?
Get or set the Flag value for this item.
no setter
PropertyBag → PropertyBag
The property bag holding property values for this object.
no setterinherited
ReminderDueBy ↔ DateTime?
Gets a value indicating which response actions are allowed on this item. Examples of response actions are Reply and Forward.
getter/setter pair
RootItemId → ItemId?
Gets Id of the root item for this item.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Schema → ServiceObjectSchema
Gets the schema associated with this type of object.
no setterinherited
Sensitivity ↔ Sensitivity?
Gets or sets the sensitivity of this item.
getter/setter pair
Service ↔ ExchangeService
Gets the ExchangeService the object is bound to.
getter/setter pairinherited
Size → int?
Gets the size of this item.
no setter
StoreEntryId → Uint8List?
Gets the store entry id.
no setter
Subject ↔ String?
Gets or sets the subject of this item.
getter/setter pair
TextBody → TextBody?
Gets the text body of the item.
no setter
UniqueBody → UniqueBody?
Gets the Id of the conversation this item is part of.
no setter
WebClientEditFormQueryString → String?
no setter
WebClientReadFormQueryString → String?
no setter

Methods

Changed() → void
Triggers dispatch of the change event.
inherited
ClearChangeLog() → void
Clears the object's change log.
inherited
Delete(DeleteMode deleteMode, [bool suppressReadReceipts = false]) → Future<void>
Deletes the item. Calling this method results in a call to EWS.
GetChangeXmlElementName() → String
Gets the name of the change XML element.
inherited
GetDeleteFieldXmlElementName() → String
Gets the name of the delete field XML element.
inherited
GetExtendedProperties() → ExtendedPropertyCollection?
Gets a list of extended properties defined on this object.
override
GetId() → ServiceId?
The unique Id of this object.
inherited
GetIdPropertyDefinition() → PropertyDefinition
The property definition for the Id of this object.
override
GetIsCustomDateTimeScopingRequired() → bool
Determines whether properties defined with ScopedDateTimePropertyDefinition require custom time zone scoping.
inherited
GetIsTimeZoneHeaderRequired(bool isUpdateOperation) → bool
Gets a value indicating whether a time zone SOAP header should be emitted in a CreateItem or UpdateItem request so this item can be property saved or updated.
override
GetLoadedPropertyDefinitions() → List<PropertyDefinitionBase?>
Gets the collection of loaded property definitions.
inherited
GetMinimumRequiredServerVersion() → ExchangeVersion
Gets the minimum required server version.
override
GetSchema() → ServiceObjectSchema
method to return the schema associated with this type of object.
override
getServiceObjectDefinitionAttribute() → ServiceObjectDefinitionAttribute
override
GetSetFieldXmlElementName() → String
Gets the name of the set field XML element.
inherited
GetXmlElementName() → String?
GetXmlElementName retrieves the XmlElementName of this type based on the EwsObjectDefinition attribute that decorates it, if present.
inherited
GetXmlElementNameOverride() → String?
This methods lets subclasses of ServiceObject override the default mechanism by which the XML element name associated with their type is retrieved.
inherited
HasUnprocessedAttachmentChanges() → bool
Gets a value indicating whether this instance has unprocessed attachment collection changes.
InternalCreate(FolderId? parentFolderId, MessageDisposition? messageDisposition, SendInvitationsMode? sendInvitationsMode) → Future<void>
Create item.
InternalDelete(DeleteMode deleteMode, SendCancellationsMode? sendCancellationsMode, AffectedTaskOccurrence? affectedTaskOccurrences, [bool suppressReadReceipts = false]) → Future<void>
Deletes the object.
override
InternalLoad(PropertySet propertySet) → Future<void>
Loads the specified set of properties on the object.
override
InternalUpdate(FolderId? parentFolderId, ConflictResolutionMode conflictResolutionMode, MessageDisposition messageDisposition, SendInvitationsOrCancellationsMode? sendInvitationsOrCancellationsMode, [bool suppressReadReceipts = false]) → Future<Item?>
Update item.
Load() → Future<void>
Loads the first class properties. Calling this method results in a call to EWS.
inherited
LoadFromXml(EwsServiceXmlReader reader, bool clearPropertyBag) → void
Loads service object from XML.
inherited
LoadFromXmlWithPropertySet(EwsServiceXmlReader reader, bool clearPropertyBag, PropertySet? requestedPropertySet, bool summaryPropertiesOnly) → void
Loads service object from XML.
inherited
LoadWithPropertySet(PropertySet propertySet) → Future<void>
Loads the specified set of properties. Calling this method results in a call to EWS.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
RemoveExtendedProperty(ExtendedPropertyDefinition extendedPropertyDefinition) → bool
Removes an extended property.
Save() → Future<void>
Saves this item in the default folder based on the item's type (for example, an e-mail message is saved to the Drafts folder). Calling this method results in at least one call to EWS. Mutliple calls to EWS might be made if attachments have been added.
SaveWithFolderId(FolderId? parentFolderId) → Future<void>
Saves this item in a specific folder. Calling this method results in at least one call to EWS. Mutliple calls to EWS might be made if attachments have been added.
SaveWithWellKnownFolderName(WellKnownFolderName parentFolderName) → Future<void>
Saves this item in a specific folder. Calling this method results in at least one call to EWS. Mutliple calls to EWS might be made if attachments have been added.
SetExtendedProperty(ExtendedPropertyDefinition extendedPropertyDefinition, Object value) → void
Creates a copy of this item in the specified folder. Calling this method results in a call to EWS.
SetSubject(String? subject) → void
Sets the subject.
ThrowIfThisIsAttachment() → void
Throws exception if this is attachment.
ThrowIfThisIsNew() → void
Throws exception if this is a new service object.
inherited
ThrowIfThisIsNotNew() → void
Throws exception if this is not a new service object.
inherited
toString() → String
A string representation of this object.
inherited
TryGetExtendedProperty<T>(ExtendedPropertyDefinition propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified extended property in this instance.
inherited
TryGetProperty(PropertyDefinitionBase propertyDefinition, OutParam<Object> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
inherited
TryGetPropertyGeneric<T>(PropertyDefinitionBase propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
inherited
Update(ConflictResolutionMode conflictResolutionMode, [bool suppressReadReceipts = false]) → Future<Item?>
Applies the local changes that have been made to this item. Calling this method results in at least one call to EWS. Mutliple calls to EWS might be made if attachments have been added or removed.
Validate() → void
Validates this instance.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes service object as XML.
inherited
WriteToXmlForUpdate(EwsServiceXmlWriter writer) → void
Writes service object for update as XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](PropertyDefinitionBase propertyDefinition) → Object?
Gets the value of specified property in this instance.
inherited

Static Methods

Bind(ExchangeService service, ItemId id) → Future<Item>
Binds to an existing item, whatever its actual type is, and loads its first class properties. Calling this method results in a call to EWS.
BindWithPropertySet(ExchangeService service, ItemId id, PropertySet propertySet) → Future<Item>
Binds to an existing item, whatever its actual type is, and loads the specified set of properties. Calling this method results in a call to EWS.