DeclineMeetingInvitationMessage class

Represents a meeting declination message.
Inheritance

Constructors

DeclineMeetingInvitationMessage(Item referenceItem)
Initializes a new instance of the

Properties

Attachments → AttachmentCollection?
Gets a list of attachments to this response.
no setterinherited
BccRecipients → EmailAddressCollection
Gets a list of recipients this response will be sent to as Bcc.
no setterinherited
Body ↔ MessageBody?
Gets or sets the body of the response.
getter/setter pairinherited
CcRecipients → EmailAddressCollection
Gets a list of recipients the response will be sent to as Cc.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
IsDeliveryReceiptRequested ↔ bool?
Gets or sets a value indicating whether delivery receipts should be sent to the sender.
getter/setter pairinherited
IsDirty → bool
Gets a value indicating whether the object has been modified and should be saved.
no setterinherited
IsNew → bool
Indicates whether this object is a real store item, or if it's a local object that has yet to be saved.
no setterinherited
IsReadReceiptRequested ↔ bool?
Gets or sets a value indicating whether read receipts will be requested from recipients of this response.
getter/setter pairinherited
ItemClass ↔ String?
getter/setter pairinherited
onChange ↔ List<IServiceObjectChangedDelegate>
Defines an event that is triggered when the service object changes.
getter/setter pairinherited
PropertyBag → PropertyBag
The property bag holding property values for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Schema → ServiceObjectSchema
Gets the schema associated with this type of object.
no setterinherited
Sensitivity ↔ Sensitivity?
Gets or sets the sensitivity of this response.
getter/setter pairinherited
Service ↔ ExchangeService
Gets the ExchangeService the object is bound to.
getter/setter pairinherited
ToRecipients → EmailAddressCollection
Gets a list of recipients the response will be sent to.
no setterinherited

Methods

Changed() → void
Triggers dispatch of the change event.
inherited
ClearChangeLog() → void
Clears the object's change log.
inherited
GetChangeXmlElementName() → String
Gets the name of the change XML element.
inherited
GetDeleteFieldXmlElementName() → String
Gets the name of the delete field XML element.
inherited
GetExtendedProperties() → ExtendedPropertyCollection?
Gets the extended properties collection.
inherited
GetId() → ServiceId?
The unique Id of this object.
inherited
GetIdPropertyDefinition() → PropertyDefinition?
The property definition for the Id of this object.
inherited
GetIsCustomDateTimeScopingRequired() → bool
Determines whether properties defined with ScopedDateTimePropertyDefinition require custom time zone scoping.
inherited
GetIsTimeZoneHeaderRequired(bool isUpdateOperation) → bool
Gets a value indicating whether a time zone SOAP header should be emitted in a CreateItem or UpdateItem request so this item can be property saved or updated.
inherited
GetLoadedPropertyDefinitions() → List<PropertyDefinitionBase?>
Gets the collection of loaded property definitions.
inherited
GetMinimumRequiredServerVersion() → ExchangeVersion
Gets the minimum required server version.
override
GetSchema() → ServiceObjectSchema
method to return the schema associated with this type of object.
inherited
getServiceObjectDefinitionAttribute() → ServiceObjectDefinitionAttribute
override
GetSetFieldXmlElementName() → String
Gets the name of the set field XML element.
inherited
GetXmlElementName() → String?
GetXmlElementName retrieves the XmlElementName of this type based on the EwsObjectDefinition attribute that decorates it, if present.
inherited
GetXmlElementNameOverride() → String?
This methods lets subclasses of ServiceObject override the default mechanism by which the XML element name associated with their type is retrieved.
inherited
InternalCreate(FolderId? destinationFolderId, MessageDisposition messageDisposition) → Future<List<Item>>
Create the response object.
inherited
InternalDelete(DeleteMode deleteMode, SendCancellationsMode sendCancellationsMode, AffectedTaskOccurrence affectedTaskOccurrences) → Future<void>
Deletes the object.
inherited
InternalLoad(PropertySet propertySet) → Future<void>
Loads the specified set of properties on the object.
inherited
Load() → Future<void>
Loads the first class properties. Calling this method results in a call to EWS.
inherited
LoadFromXml(EwsServiceXmlReader reader, bool clearPropertyBag) → void
Loads service object from XML.
inherited
LoadFromXmlWithPropertySet(EwsServiceXmlReader reader, bool clearPropertyBag, PropertySet? requestedPropertySet, bool summaryPropertiesOnly) → void
Loads service object from XML.
inherited
LoadWithPropertySet(PropertySet propertySet) → Future<void>
Loads the specified set of properties. Calling this method results in a call to EWS.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Save() → Future<MeetingResponse>
Saves the response in the Drafts folder. Calling this method results in a call to EWS.
inherited
SaveWithFolderId(FolderId destinationFolderId) → Future<MeetingResponse>
Saves the response in the specified folder. Calling this method results in a call to EWS.
inherited
SaveWithWellKnownFolder(WellKnownFolderName destinationFolderName) → Future<MeetingResponse>
Saves the response in the specified folder. Calling this method results in a call to EWS.
inherited
Send() → Future<CalendarActionResults>
Saves the response in the specified folder. Calling this method results in a call to EWS.
inherited
SendAndSaveCopy() → Future<CalendarActionResults>
Sends this response ans saves a copy in the Sent Items folder. Calling this method results in a call to EWS.
inherited
SendAndSaveCopyWithFolderId(FolderId destinationFolderId) → Future<CalendarActionResults>
Sends this response ans saves a copy in the specified folder. Calling this method results in a call to EWS.
inherited
SendAndSaveCopyWithWellKnownFolder(WellKnownFolderName destinationFolderName) → Future<CalendarActionResults>
Sends this response and saves a copy in the specified folder. Calling this method results in a call to EWS.
inherited
ThrowIfThisIsNew() → void
Throws exception if this is a new service object.
inherited
ThrowIfThisIsNotNew() → void
Throws exception if this is not a new service object.
inherited
toString() → String
A string representation of this object.
inherited
TryGetExtendedProperty<T>(ExtendedPropertyDefinition propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified extended property in this instance.
inherited
TryGetProperty(PropertyDefinitionBase propertyDefinition, OutParam<Object> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
inherited
TryGetPropertyGeneric<T>(PropertyDefinitionBase propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
inherited
Validate() → void
Validates this instance.
inherited
WriteToXml(EwsServiceXmlWriter writer) → void
Writes service object as XML.
inherited
WriteToXmlForUpdate(EwsServiceXmlWriter writer) → void
Writes service object for update as XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](PropertyDefinitionBase propertyDefinition) → Object?
Gets the value of specified property in this instance.
inherited