ContactSchema class

Represents the schem for contacts.
Inheritance

Constructors

ContactSchema()

Properties

first → PropertyDefinition
The first element.
no setterinherited
FirstClassProperties → List<PropertyDefinition>
Gets the list of first class properties for this service object type.
no setterinherited
FirstClassSummaryProperties → List<PropertyDefinition>
Gets the list of first class summary properties for this service object type.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
IndexedProperties → List<IndexedPropertyDefinition>
Gets the list of indexed properties for this service object type.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<PropertyDefinition>
Obtains an enumerator for the properties of the schema.
no setterinherited
last → PropertyDefinition
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → PropertyDefinition
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(PropertyDefinition element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → PropertyDefinition
Returns the indexth element.
inherited
every(bool test(PropertyDefinition element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(PropertyDefinition element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(PropertyDefinition element), {PropertyDefinition orElse()?}) → PropertyDefinition
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, PropertyDefinition element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<PropertyDefinition> other) → Iterable<PropertyDefinition>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(PropertyDefinition element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(PropertyDefinition element), {PropertyDefinition orElse()?}) → PropertyDefinition
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(PropertyDefinition e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(PropertyDefinition combine(PropertyDefinition value, PropertyDefinition element)) → PropertyDefinition
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
RegisterIndexedProperty(IndexedPropertyDefinition indexedProperty) → void
Registers an indexed property.
inherited
RegisterInternalProperty(PropertyDefinition property) → void
Registers an schema property.
inherited
RegisterProperties() → void
Registers properties.
override
RegisterProperty(PropertyDefinition property) → void
Registers a schema property that will be visible to developers.
inherited
singleWhere(bool test(PropertyDefinition element), {PropertyDefinition orElse()?}) → PropertyDefinition
The single element that satisfies test.
inherited
skip(int count) → Iterable<PropertyDefinition>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(PropertyDefinition element)) → Iterable<PropertyDefinition>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<PropertyDefinition>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(PropertyDefinition element)) → Iterable<PropertyDefinition>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<PropertyDefinition>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<PropertyDefinition>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryGetPropertyDefinition(String xmlElementName, OutParam<PropertyDefinition> propertyDefinitionOutParam) → bool
Tries to get property definition.
inherited
where(bool test(PropertyDefinition element)) → Iterable<PropertyDefinition>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

Alias ↔ PropertyDefinition
Defines the Alias property.
getter/setter pair
AssistantName ↔ PropertyDefinition
Defines the AssistantName property.
getter/setter pair
AssistantPhone ↔ IndexedPropertyDefinition
Defines the AssistentPhone property.
getter/setter pair
Birthday ↔ PropertyDefinition
Defines the Birthday property.
getter/setter pair
BusinessAddressCity ↔ IndexedPropertyDefinition
Defines the BusinessAddressCity property.
getter/setter pair
BusinessAddressCountryOrRegion ↔ IndexedPropertyDefinition
Defines the BusinessAddressCountryOrRegion property.
getter/setter pair
BusinessAddressPostalCode ↔ IndexedPropertyDefinition
Defines the BusinessAddressPostalCode property.
getter/setter pair
BusinessAddressState ↔ IndexedPropertyDefinition
Defines the BusinessAddressState property.
getter/setter pair
BusinessAddressStreet ↔ IndexedPropertyDefinition
Defines the BusinessAddressStreet property.
getter/setter pair
BusinessFax ↔ IndexedPropertyDefinition
Defines the BusinessFax property.
getter/setter pair
BusinessHomePage ↔ PropertyDefinition
Defines the BusinessHomePage property.
getter/setter pair
BusinessPhone ↔ IndexedPropertyDefinition
Defines the BusinessPhone property.
getter/setter pair
BusinessPhone2 ↔ IndexedPropertyDefinition
Defines the BusinessPhone2 property.
getter/setter pair
Callback ↔ IndexedPropertyDefinition
Defines the Callback property.
getter/setter pair
CarPhone ↔ IndexedPropertyDefinition
Defines the CarPhone property.
getter/setter pair
Children ↔ PropertyDefinition
Defines the Children property.
getter/setter pair
Companies ↔ PropertyDefinition
Defines the Companies property.
getter/setter pair
CompanyMainPhone ↔ IndexedPropertyDefinition
Defines the CompanyMainPhone property.
getter/setter pair
CompanyName ↔ PropertyDefinition
Defines the CompanyName property.
getter/setter pair
CompleteName ↔ PropertyDefinition
Defines the CompleteName property.
getter/setter pair
ContactSource ↔ PropertyDefinition
Defines the ContactSource property.
getter/setter pair
Department ↔ PropertyDefinition
Defines the Department property.
getter/setter pair
DirectoryId ↔ PropertyDefinition
Defines the UserSMIMECertificate property.
getter/setter pair
DirectReports ↔ PropertyDefinition
Defines the DirectReports property.
getter/setter pair
DisplayName ↔ PropertyDefinition
Defines the DisplayName property.
getter/setter pair
EmailAddress1 ↔ IndexedPropertyDefinition
Defines the EmailAddress1 property.
getter/setter pair
EmailAddress2 ↔ IndexedPropertyDefinition
Defines the EmailAddress2 property.
getter/setter pair
EmailAddress3 ↔ IndexedPropertyDefinition
Defines the EmailAddress3 property.
getter/setter pair
EmailAddresses ↔ PropertyDefinition
Defines the EmailAddresses property.
getter/setter pair
FileAs ↔ PropertyDefinition
Defines the FileAs property.
getter/setter pair
FileAsMapping ↔ PropertyDefinition
Defines the FileAsMapping property.
getter/setter pair
Generation ↔ PropertyDefinition
Defines the Generation property.
getter/setter pair
GivenName ↔ PropertyDefinition
Defines the GivenName property.
getter/setter pair
HasPicture ↔ PropertyDefinition
Defines the HasPicture property.
getter/setter pair
HomeAddressCity ↔ IndexedPropertyDefinition
Defines the HomeAddressCity property.
getter/setter pair
HomeAddressCountryOrRegion ↔ IndexedPropertyDefinition
Defines the HomeAddressCountryOrRegion property.
getter/setter pair
HomeAddressPostalCode ↔ IndexedPropertyDefinition
Defines the HomeAddressPostalCode property.
getter/setter pair
HomeAddressState ↔ IndexedPropertyDefinition
Defines the HomeAddressState property.
getter/setter pair
HomeAddressStreet ↔ IndexedPropertyDefinition
Defines the HomeAddressStreet property.
getter/setter pair
HomeFax ↔ IndexedPropertyDefinition
Defines the HomeFax property.
getter/setter pair
HomePhone ↔ IndexedPropertyDefinition
Defines the HomePhone property.
getter/setter pair
HomePhone2 ↔ IndexedPropertyDefinition
Defines the HomePhone2 property.
getter/setter pair
ImAddress1 ↔ IndexedPropertyDefinition
Defines the ImAddress1 property.
getter/setter pair
ImAddress2 ↔ IndexedPropertyDefinition
Defines the ImAddress2 property.
getter/setter pair
ImAddress3 ↔ IndexedPropertyDefinition
Defines the ImAddress3 property.
getter/setter pair
ImAddresses ↔ PropertyDefinition
Defines the ImAddresses property.
getter/setter pair
Initials ↔ PropertyDefinition
Defines the Initials property.
getter/setter pair
Instance ↔ ContactSchema
getter/setter pair
Isdn ↔ IndexedPropertyDefinition
Defines the Isdn property.
getter/setter pair
JobTitle ↔ PropertyDefinition
Defines the JobTitle property.
getter/setter pair
Manager ↔ PropertyDefinition
Defines the Manager property.
getter/setter pair
ManagerMailbox ↔ PropertyDefinition
Defines the ManagerMailbox property.
getter/setter pair
MiddleName ↔ PropertyDefinition
Defines the MiddleName property.
getter/setter pair
Mileage ↔ PropertyDefinition
Defines the Mileage property.
getter/setter pair
MobilePhone ↔ IndexedPropertyDefinition
Defines the MobilePhone property.
getter/setter pair
NickName ↔ PropertyDefinition
Defines the NickName property.
getter/setter pair
Notes ↔ PropertyDefinition
Defines the Notes property.
getter/setter pair
OfficeLocation ↔ PropertyDefinition
Defines the OfficeLocation property.
getter/setter pair
OtherAddressCity ↔ IndexedPropertyDefinition
Defines the OtherAddressCity property.
getter/setter pair
OtherAddressCountryOrRegion ↔ IndexedPropertyDefinition
Defines the OtherAddressCountryOrRegion property.
getter/setter pair
OtherAddressPostalCode ↔ IndexedPropertyDefinition
Defines the OtherAddressPostalCode property.
getter/setter pair
OtherAddressState ↔ IndexedPropertyDefinition
Defines the OtherAddressState property.
getter/setter pair
OtherAddressStreet ↔ IndexedPropertyDefinition
Defines the OtherAddressStreet property.
getter/setter pair
OtherFax ↔ IndexedPropertyDefinition
Defines the OtherFax property.
getter/setter pair
OtherTelephone ↔ IndexedPropertyDefinition
Defines the OtherTelephone property.
getter/setter pair
Pager ↔ IndexedPropertyDefinition
Defines the Pager property.
getter/setter pair
PhoneNumbers ↔ PropertyDefinition
Defines the PhoneNumbers property.
getter/setter pair
PhoneticFirstName ↔ PropertyDefinition
Defines the PhoneticFirstName property.
getter/setter pair
PhoneticFullName ↔ PropertyDefinition
Defines the PhoneticFullName property.
getter/setter pair
PhoneticLastName ↔ PropertyDefinition
Defines the PhoneticLastName property.
getter/setter pair
Photo ↔ PropertyDefinition
Defines the Photo property.
getter/setter pair
PhysicalAddresses ↔ PropertyDefinition
Defines the PhysicalAddresses property.
getter/setter pair
PrimaryPhone ↔ IndexedPropertyDefinition
Defines the PrimaryPhone property.
getter/setter pair
Profession ↔ PropertyDefinition
Defines the PostalAddressIndex property.
getter/setter pair
RadioPhone ↔ IndexedPropertyDefinition
Defines the RadioPhone property.
getter/setter pair
SpouseName ↔ PropertyDefinition
Defines the SpouseName property.
getter/setter pair
Surname ↔ PropertyDefinition
Defines the Surname property.
getter/setter pair
Telex ↔ IndexedPropertyDefinition
Defines the Telex property.
getter/setter pair
TtyTddPhone ↔ IndexedPropertyDefinition
Defines the TtyTddPhone property.
getter/setter pair
WeddingAnniversary ↔ PropertyDefinition
Defines the WeddingAnniversary property.
getter/setter pair