ItemSchema class

Represents the schema for generic items.
Inheritance
Implementers

Constructors

ItemSchema()
Initializes a new instance of the

Properties

first → PropertyDefinition
The first element.
no setterinherited
FirstClassProperties → List<PropertyDefinition>
Gets the list of first class properties for this service object type.
no setterinherited
FirstClassSummaryProperties → List<PropertyDefinition>
Gets the list of first class summary properties for this service object type.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
IndexedProperties → List<IndexedPropertyDefinition>
Gets the list of indexed properties for this service object type.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<PropertyDefinition>
Obtains an enumerator for the properties of the schema.
no setterinherited
last → PropertyDefinition
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → PropertyDefinition
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(PropertyDefinition element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → PropertyDefinition
Returns the indexth element.
inherited
every(bool test(PropertyDefinition element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(PropertyDefinition element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(PropertyDefinition element), {PropertyDefinition orElse()?}) → PropertyDefinition
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, PropertyDefinition element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<PropertyDefinition> other) → Iterable<PropertyDefinition>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(PropertyDefinition element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(PropertyDefinition element), {PropertyDefinition orElse()?}) → PropertyDefinition
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(PropertyDefinition e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(PropertyDefinition combine(PropertyDefinition value, PropertyDefinition element)) → PropertyDefinition
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
RegisterIndexedProperty(IndexedPropertyDefinition indexedProperty) → void
Registers an indexed property.
inherited
RegisterInternalProperty(PropertyDefinition property) → void
Registers an schema property.
inherited
RegisterProperties() → void
Registers properties.
override
RegisterProperty(PropertyDefinition property) → void
Registers a schema property that will be visible to developers.
inherited
singleWhere(bool test(PropertyDefinition element), {PropertyDefinition orElse()?}) → PropertyDefinition
The single element that satisfies test.
inherited
skip(int count) → Iterable<PropertyDefinition>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(PropertyDefinition element)) → Iterable<PropertyDefinition>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<PropertyDefinition>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(PropertyDefinition element)) → Iterable<PropertyDefinition>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<PropertyDefinition>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<PropertyDefinition>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryGetPropertyDefinition(String xmlElementName, OutParam<PropertyDefinition> propertyDefinitionOutParam) → bool
Tries to get property definition.
inherited
where(bool test(PropertyDefinition element)) → Iterable<PropertyDefinition>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

Attachments ↔ PropertyDefinition
Defines the Attachments property.
getter/setter pair
Body ↔ PropertyDefinition
Defines the Body property.
getter/setter pair
Categories ↔ PropertyDefinition
Defines the Categories property.
getter/setter pair
ConversationId ↔ PropertyDefinition
Defines the ConversationId property.
getter/setter pair
Culture ↔ PropertyDefinition
Defines the Culture property.
getter/setter pair
DateTimeCreated ↔ PropertyDefinition
Defines the DateTimeCreated property.
getter/setter pair
DateTimeReceived ↔ PropertyDefinition
Defines the DateTimeReceived property.
getter/setter pair
DateTimeSent ↔ PropertyDefinition
Defines the InternetMessageHeaders property.
getter/setter pair
DisplayCc ↔ PropertyDefinition
Defines the DisplayCc property.
getter/setter pair
DisplayTo ↔ PropertyDefinition
Defines the DisplayTo property.
getter/setter pair
EffectiveRights ↔ PropertyDefinition
Defines the EffectiveRights property.
getter/setter pair
Flag ↔ PropertyDefinition
Defines the NormalizedBody property.
getter/setter pair
HasAttachments ↔ PropertyDefinition
Defines the HasAttachments property.
getter/setter pair
Id ↔ PropertyDefinition
Defines the Id property.
getter/setter pair
Importance ↔ PropertyDefinition
Defines the Importance property.
getter/setter pair
InReplyTo ↔ PropertyDefinition
Defines the InReplyTo property.
getter/setter pair
Instance ↔ ItemSchema
Defines the IconIndex property.
getter/setter pair
InstanceKey ↔ PropertyDefinition
Defines the InstanceKey property.
getter/setter pair
IsAssociated ↔ PropertyDefinition
Defines the IsAssociated property.
getter/setter pair
IsDraft ↔ PropertyDefinition
Defines the IsDraft property.
getter/setter pair
IsFromMe ↔ PropertyDefinition
Defines the IsFromMe property.
getter/setter pair
IsReminderSet ↔ PropertyDefinition
Defines the IsReminderSet property.
getter/setter pair
IsResend ↔ PropertyDefinition
Defines the IsResend property.
getter/setter pair
IsSubmitted ↔ PropertyDefinition
Defines the IsSubmitted property.
getter/setter pair
IsUnmodified ↔ PropertyDefinition
Defines the IsUnmodified property.
getter/setter pair
ItemClass ↔ PropertyDefinition
Defines the ItemClass property.
getter/setter pair
LastModifiedName ↔ PropertyDefinition
Defines the LastModifiedName property.
getter/setter pair
LastModifiedTime ↔ PropertyDefinition
Defines the LastModifiedTime property.
getter/setter pair
MimeContent ↔ PropertyDefinition
Defines the MimeContent property.
getter/setter pair
ParentFolderId ↔ PropertyDefinition
Defines the MimeContentUTF8 property.
getter/setter pair
Preview ↔ PropertyDefinition
Defines the PolicyTag property.
getter/setter pair
ReminderDueBy ↔ PropertyDefinition
Defines the AllowedResponseActions property.
getter/setter pair
ReminderMinutesBeforeStart ↔ PropertyDefinition
Defines the ReminderMinutesBeforeStart property.
getter/setter pair
Sensitivity ↔ PropertyDefinition
Defines the Sensitivity property.
getter/setter pair
Size ↔ PropertyDefinition
Defines the Size property.
getter/setter pair
StoreEntryId ↔ PropertyDefinition
Defines the StoreEntryId property.
getter/setter pair
Subject ↔ PropertyDefinition
Defines the Subject property.
getter/setter pair
TextBody ↔ PropertyDefinition
Defines the TextBody property.
getter/setter pair
UniqueBody ↔ PropertyDefinition
Defines the UniqueBody property.
getter/setter pair
WebClientEditFormQueryString ↔ PropertyDefinition
Defines the WebClientEditFormQueryString property.
getter/setter pair
WebClientReadFormQueryString ↔ PropertyDefinition
Defines the WebClientReadFormQueryString property.
getter/setter pair