ServiceObject class abstract

Represents the base class for all item and folder types.
Implementers

Constructors

ServiceObject(ExchangeService service)
constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
IsDirty → bool
Gets a value indicating whether the object has been modified and should be saved.
no setter
IsNew → bool
Indicates whether this object is a real store item, or if it's a local object that has yet to be saved.
no setter
onChange ↔ List<IServiceObjectChangedDelegate>
Defines an event that is triggered when the service object changes.
getter/setter pair
PropertyBag → PropertyBag
The property bag holding property values for this object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Schema → ServiceObjectSchema
Gets the schema associated with this type of object.
no setter
Service ↔ ExchangeService
Gets the ExchangeService the object is bound to.
getter/setter pair

Methods

Changed() → void
Triggers dispatch of the change event.
ClearChangeLog() → void
Clears the object's change log.
GetChangeXmlElementName() → String
Gets the name of the change XML element.
GetDeleteFieldXmlElementName() → String
Gets the name of the delete field XML element.
GetExtendedProperties() → ExtendedPropertyCollection?
Gets the extended properties collection.
GetId() → ServiceId?
The unique Id of this object.
GetIdPropertyDefinition() → PropertyDefinition?
The property definition for the Id of this object.
GetIsCustomDateTimeScopingRequired() → bool
Determines whether properties defined with ScopedDateTimePropertyDefinition require custom time zone scoping.
GetIsTimeZoneHeaderRequired(bool isUpdateOperation) → bool
Gets a value indicating whether a time zone SOAP header should be emitted in a CreateItem or UpdateItem request so this item can be property saved or updated.
GetLoadedPropertyDefinitions() → List<PropertyDefinitionBase?>
Gets the collection of loaded property definitions.
GetMinimumRequiredServerVersion() → ExchangeVersion
Gets the minimum required server version.
GetSchema() → ServiceObjectSchema
method to return the schema associated with this type of object.
getServiceObjectDefinitionAttribute() → ServiceObjectDefinitionAttribute?
GetSetFieldXmlElementName() → String
Gets the name of the set field XML element.
GetXmlElementName() → String?
GetXmlElementName retrieves the XmlElementName of this type based on the EwsObjectDefinition attribute that decorates it, if present.
GetXmlElementNameOverride() → String?
This methods lets subclasses of ServiceObject override the default mechanism by which the XML element name associated with their type is retrieved.
InternalDelete(DeleteMode deleteMode, SendCancellationsMode sendCancellationsMode, AffectedTaskOccurrence affectedTaskOccurrences) → Future<void>
Deletes the object.
InternalLoad(PropertySet propertySet) → Future<void>
Loads the specified set of properties on the object.
Load() → Future<void>
Loads the first class properties. Calling this method results in a call to EWS.
LoadFromXml(EwsServiceXmlReader reader, bool clearPropertyBag) → void
Loads service object from XML.
LoadFromXmlWithPropertySet(EwsServiceXmlReader reader, bool clearPropertyBag, PropertySet? requestedPropertySet, bool summaryPropertiesOnly) → void
Loads service object from XML.
LoadWithPropertySet(PropertySet propertySet) → Future<void>
Loads the specified set of properties. Calling this method results in a call to EWS.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ThrowIfThisIsNew() → void
Throws exception if this is a new service object.
ThrowIfThisIsNotNew() → void
Throws exception if this is not a new service object.
toString() → String
A string representation of this object.
inherited
TryGetExtendedProperty<T>(ExtendedPropertyDefinition propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified extended property in this instance.
TryGetProperty(PropertyDefinitionBase propertyDefinition, OutParam<Object> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
TryGetPropertyGeneric<T>(PropertyDefinitionBase propertyDefinition, OutParam<T> propertyValueOutParam) → bool
Try to get the value of a specified property in this instance.
Validate() → void
Validates this instance.
WriteToXml(EwsServiceXmlWriter writer) → void
Writes service object as XML.
WriteToXmlForUpdate(EwsServiceXmlWriter writer) → void
Writes service object for update as XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](PropertyDefinitionBase propertyDefinition) → Object?
Gets the value of specified property in this instance.