ServiceObjectInfo class

ServiceObjectInfo contains metadata on how to map from an element name to a ServiceObject type as well as how to map from a ServiceObject type to appropriate constructors.

Constructors

ServiceObjectInfo()
Default constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ServiceObjectConstructorsWithAttachmentParam → Map<Type, CreateServiceObjectWithAttachmentParam>
Return Dictionary that maps from ServiceObject Type to CreateServiceObjectWithAttachmentParam delegate with ItemAttachment parameter.
no setter
ServiceObjectConstructorsWithServiceParam → Map<Type, CreateServiceObjectWithServiceParam>
Return Dictionary that maps from ServiceObject Type to CreateServiceObjectWithServiceParam delegate with ExchangeService parameter.
no setter
XmlElementNameToServiceObjectClassMap → Map<String, Type>
Return Dictionary that maps from element name to ServiceObject Type.
no setter

Methods

AddServiceObjectType(String xmlElementName, Type type, CreateServiceObjectWithServiceParam createServiceObjectWithServiceParam, CreateServiceObjectWithAttachmentParam? createServiceObjectWithAttachmentParam) → void
Adds specified type of service object to map.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited