SimplePropertyBag<TKey> class

Represents a simple property bag.
Implemented types
Mixed-in types

Constructors

SimplePropertyBag()
Initializes a new instance of the

Properties

AddedItems → Iterable<TKey>
Gets the added items.
no setter
first → MapEntry<TKey, Object>
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<MapEntry<TKey, Object>>
Gets an enumerator that iterates through the elements of the collection.
no setteroverride
last → MapEntry<TKey, Object>
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
ModifiedItems → Iterable<TKey>
Gets the modified items.
no setter
RemovedItems → Iterable<TKey>
Gets the removed items.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → MapEntry<TKey, Object>
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

addOnChangeEvent(IPropertyBagChangedDelegate<TKey> change) → void
any(bool test(MapEntry<TKey, Object> element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
ClearChangeLog() → void
Clears the change log.
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
ContainsKey(TKey key) → bool
Determines whether the specified key is in the property bag.
elementAt(int index) → MapEntry<TKey, Object>
Returns the indexth element.
inherited
every(bool test(MapEntry<TKey, Object> element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(MapEntry<TKey, Object> element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(MapEntry<TKey, Object> element), {MapEntry<TKey, Object> orElse()?}) → MapEntry<TKey, Object>
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, MapEntry<TKey, Object> element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<MapEntry<TKey, Object>> other) → Iterable<MapEntry<TKey, Object>>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(MapEntry<TKey, Object> element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(MapEntry<TKey, Object> element), {MapEntry<TKey, Object> orElse()?}) → MapEntry<TKey, Object>
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(MapEntry<TKey, Object> e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(MapEntry<TKey, Object> combine(MapEntry<TKey, Object> value, MapEntry<TKey, Object> element)) → MapEntry<TKey, Object>
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
removeChangeEvent(IPropertyBagChangedDelegate<TKey> change) → void
singleWhere(bool test(MapEntry<TKey, Object> element), {MapEntry<TKey, Object> orElse()?}) → MapEntry<TKey, Object>
The single element that satisfies test.
inherited
skip(int count) → Iterable<MapEntry<TKey, Object>>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(MapEntry<TKey, Object> element)) → Iterable<MapEntry<TKey, Object>>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<MapEntry<TKey, Object>>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(MapEntry<TKey, Object> element)) → Iterable<MapEntry<TKey, Object>>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<MapEntry<TKey, Object>>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<MapEntry<TKey, Object>>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryGetValue(TKey key, OutParam<Object> valueOutParam) → bool
Tries to get value.
where(bool test(MapEntry<TKey, Object> element)) → Iterable<MapEntry<TKey, Object>>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](TKey key) → dynamic
Gets or sets the
operator []=(TKey key, Object? value) → void