ExchangeCredentials class abstract

Base class of Exchange credential types.
Implemented types
Implementers

Constructors

ExchangeCredentials()

Properties

hashCode → int
The hash code for this object.
no setterinherited
NeedSignature → bool
Gets the flag indicating whether any sign action need taken.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

AdjustUrl(Uri url) → Uri
Adjusts the URL endpoint based on the credentials.
EmitExtraSoapHeaderNamespaceAliases(XmlWriter? writer) → void
Emit any extra necessary namespace aliases for the SOAP:header block.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
PreAuthenticate() → Future<void>
This method is called to pre-authenticate credentials before a service request is made.
PrepareWebRequest(IEwsHttpWebRequest request) → void
This method is called to apply credentials to a service request before the request is made.
SerializeExtraSoapHeaders(XmlWriter? writer, String webMethodName) → void
Serialize any extra necessary SOAP headers. This is used for authentication schemes that rely on WS-Security, or for endpoints requiring WS-Addressing.
SerializeWSSecurityHeaders(XmlWriter? writer) → void
Serialize SOAP headers used for authentication schemes that rely on WS-Security
Sign(MemoryStream memoryStream) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

WsSecurityPathSuffix → String
final

Static Methods

GetUriWithoutSuffix(Uri url) → String
Performs an implicit conversion from