DayOfTheWeekIndex enum

Defines the index of a week day within a month.
Inheritance
Available extensions

Values

First → const DayOfTheWeekIndex
The first specific day of the week in the month. For example, the first Tuesday of the month.
Second → const DayOfTheWeekIndex
The second specific day of the week in the month. For example, the second Tuesday of the month.
Third → const DayOfTheWeekIndex
The third specific day of the week in the month. For example, the third Tuesday of the month.
Fourth → const DayOfTheWeekIndex
The fourth specific day of the week in the month. For example, the fourth Tuesday of the month.
Last → const DayOfTheWeekIndex
The last specific day of the week in the month. For example, the last Tuesday of the month.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DayOfTheWeekIndex>
A constant List of the values in this enum, in order of their declaration.