AccountIsLockedException class

Represents an error that occurs when the account that is being accessed is locked and requires user interaction to be unlocked.
Inheritance

Constructors

AccountIsLockedException(String message, Uri accountUnlockUrl, Exception innerException)
Initializes a new instance of the

Properties

AccountUnlockUrl ↔ Uri?
Gets the URL of a web page where the user can navigate to unlock his or her account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited