AutodiscoverRemoteException class

Represents an exception that is thrown when the Autodiscover service returns an error.
Inheritance

Constructors

AutodiscoverRemoteException(String message, AutodiscoverError? error)
Initializes a new instance of the

Properties

Error → AutodiscoverError?
Initializes a new instance of the
no setter
error → AutodiscoverError?
final
hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited