AutodiscoverResponseException class

Represents an exception from an autodiscover error response.
Inheritance

Constructors

AutodiscoverResponseException(AutodiscoverErrorCode? errorCode, String message)
Initializes a new instance of the

Properties

ErrorCode → AutodiscoverErrorCode?
Initializes a new instance of the
no setter
errorCode → AutodiscoverErrorCode?
Error code when Autodiscover service operation failed remotely.
final
hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited