BatchServiceResponseException<TResponse extends ServiceResponse> class abstract

Represents a remote service exception that can have multiple service responses.
Inheritance
Implementers

Constructors

BatchServiceResponseException(ServiceResponseCollection<TResponse>? responses, String message, [Exception? innerException])
Initializes a new instance of MultiServiceResponseException.

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String
finalinherited
responses ↔ ServiceResponseCollection<TResponse>?
The list of responses returned by the web method.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ServiceResponses → ServiceResponseCollection<TResponse>?
Initializes a new instance of the
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited