CreateAttachmentException class

Represents an error that occurs when a call to the CreateAttachment web method fails.
Inheritance

Constructors

CreateAttachmentException(ServiceResponseCollection<CreateAttachmentResponse> serviceResponses, String message, [Exception? innerException])
Initializes a new instance of CreateAttachmentException.

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String
finalinherited
responses ↔ ServiceResponseCollection<CreateAttachmentResponse>?
The list of responses returned by the web method.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ServiceResponses → ServiceResponseCollection<CreateAttachmentResponse>?
Initializes a new instance of the
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited