ServerBusyException class

Represents a server busy exception found in a service response.
Inheritance

Constructors

ServerBusyException(ServiceResponse response)
Initializes a new instance of the

Properties

BackOffMilliseconds → int?
Initializes a new instance of the
no setter
ErrorCode → ServiceError?
Gets the service error code.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
Message → String?
Gets a message that describes the current exception.
no setterinherited
message → String
finalinherited
Response → ServiceResponse
Initializes a new instance of the
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

BackOffMillisecondsKey → const String