ServiceObjectPropertyException class

Represents an error that occurs when an operation on a property fails.
Inheritance

Constructors

ServiceObjectPropertyException(PropertyDefinitionBase propertyDefinition)
ServiceObjectPropertyException constructor.
ServiceObjectPropertyException.withMessage(String message, PropertyDefinitionBase propertyDefinition)
ServiceObjectPropertyException Constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String?
finalinherited
name ↔ String?
The name of the property that is at the origin of the exception.
getter/setter pairinherited
propertyDefinition ↔ PropertyDefinitionBase?
The definition of the property that is at the origin of the exception.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited