ServiceRemoteException class

Represents an error that occurs when a service operation fails remotely.
Implemented types
Implementers

Constructors

ServiceRemoteException([String message = "", Exception? innerException = null, StackTrace? innerStackTrace = null])
ServiceRemoteException Constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
final
innerStackTrace → StackTrace?
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited