ServiceResponseException class

Represents a remote service exception that has a single response.
Inheritance
Implementers

Constructors

ServiceResponseException(ServiceResponse _response)
Initializes a new instance of the

Properties

ErrorCode → ServiceError?
Gets the service error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
Message → String?
Gets a message that describes the current exception.
no setter
message → String
finalinherited
Response → ServiceResponse
Initializes a new instance of the
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited