ServiceXmlSerializationException class

Represents an error that occurs when the XML for a request cannot be serialized.
Inheritance

Constructors

ServiceXmlSerializationException(dynamic message, [Exception? innerException, StackTrace? stackTrace])
ServiceXmlSerializationException Constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → Exception?
finalinherited
innerStackTrace → StackTrace?
finalinherited
message → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited