EwsHttpWebExceptionResponse class

Implemented types

Constructors

EwsHttpWebExceptionResponse(WebException _webException)

Properties

ContentEncoding → String
Gets the method that is used to encode the body of the response.
no setteroverride
ContentType → String
Gets the content type of the response.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
Headers → WebHeaderCollection
Gets the headers that are associated with this response from the server.
no setteroverride
ResponseUri → Uri
Gets the URI of the Internet resource that responded to the request.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
StatusCode → int
Gets the status of the response.
no setteroverride
StatusDescription → String
Gets the status description returned with the response.
no setteroverride

Methods

Close() → void
Closes the response stream.
override
Dispose() → dynamic
override
GetResponseStream() → Stream<List<int>>
Gets the stream that is used to read the body of the response from the server.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited