WebException class

Implemented types

Constructors

WebException(WebExceptionStatus Status, HttpClientRequest? Request, HttpClientResponse Response)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
no setter
Request → HttpClientRequest?
final
Response → HttpClientResponse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Status → WebExceptionStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited