WebHeaderCollection class

Constructors

WebHeaderCollection()

Properties

AllKeys → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

Add(String headerName, String? headerValue) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Set(String headerName, String? headerValue) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String headerName) → String?
operator []=(String headerName, String headerValue) → void