ICustomUpdateSerializer class abstract

Interface defined for properties that produce their own update serialization.
Implementers

Constructors

ICustomUpdateSerializer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteDeleteUpdateToXml(EwsServiceXmlWriter writer, ServiceObject? ewsObject) → bool
Writes the deletion update to XML.
WriteSetUpdateToXml(EwsServiceXmlWriter writer, ServiceObject? ewsObject, PropertyDefinition propertyDefinition) → bool
Writes the update to XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited