IEwsHttpWebResponse class abstract

Interface representing HTTP web response.
Implemented types
Implementers

Constructors

IEwsHttpWebResponse()

Properties

ContentEncoding → String
Gets the method that is used to encode the body of the response.
no setter
ContentType → String
Gets the content type of the response.
no setter
hashCode → int
The hash code for this object.
no setterinherited
Headers → WebHeaderCollection
Gets the headers that are associated with this response from the server.
no setter
ResponseUri → Uri
Gets the URI of the Internet resource that responded to the request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
StatusCode → int
Gets the status of the response.
no setter
StatusDescription → String
Gets the status description returned with the response.
no setter

Methods

Close() → void
Closes the response stream.
Dispose() → dynamic
inherited
GetResponseStream() → Stream<List<int>>
Gets the stream that is used to read the body of the response from the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited