IOwnedProperty class abstract

Complex properties that implement that abstract class are owned by an instance of EwsObject. For this reason, they also cannot be shared.
Implementers

Constructors

IOwnedProperty()

Properties

hashCode → int
The hash code for this object.
no setterinherited
Owner ↔ ServiceObject?
Gets or sets the owner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited