FolderEvent class

Represents an event that applies to a folder.
Inheritance

Constructors

FolderEvent(EventType? eventType, DateTime? timestamp)
Initializes a new instance of the

Properties

EventType → EventType?
Gets the type of this event.
no setterinherited
eventType ↔ EventType?
Type of this event.
getter/setter pairinherited
FolderId → FolderId?
Gets the Id of the folder this event applies to.
no setter
hashCode → int
The hash code for this object.
no setterinherited
OldFolderId → FolderId?
Gets the Id of the folder that was moved or copied. OldFolderId is only meaningful when EventType is equal to either EventType.Moved or EventType.Copied. For all other event types, OldFolderId is null.
no setter
OldParentFolderId ↔ FolderId?
Gets the Id of the old parent folder of the item or folder this event applies to. OldParentFolderId is only meaningful when EventType is equal to either EventType.Moved or EventType.Copied. For all other event types, OldParentFolderId is null.
getter/setter pairinherited
oldParentFolderId ↔ FolderId?
Id of the old prarent foldero of the item or folder this event applies to. This property is only meaningful when EventType is equal to either EventType.Moved or EventType.Copied. For all other event types, oldParentFolderId will be null.
getter/setter pairinherited
ParentFolderId ↔ FolderId?
Gets the Id of the parent folder of the item or folder this event applie to.
getter/setter pairinherited
parentFolderId ↔ FolderId?
Id of parent folder of the item or folder this event applies to.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TimeStamp → DateTime?
Gets the date and time when the event occurred.
no setterinherited
timestamp ↔ DateTime?
Date and time when the event occurred.
getter/setter pairinherited
UnreadCount → int?
Gets the new number of unread messages. This is is only meaningful when EventType is equal to EventType.Modified. For all other event types, UnreadCount is null.
no setter

Methods

InternalLoadFromXml(EwsServiceXmlReader reader) → void
Load from XML.
override
LoadFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads this NotificationEvent from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited