GetEventsResults class

Represents a collection of notification events.

Constructors

GetEventsResults()
Initializes a new instance of the

Properties

AllEvents → List<NotificationEvent>
Gets the collection of all events.
no setter
FolderEvents → Iterable<FolderEvent>
Gets the collection of folder events.
no setter
hashCode → int
The hash code for this object.
no setterinherited
ItemEvents → Iterable<ItemEvent>
Gets the collection of item events.
no setter
MoreEventsAvailable → bool?
Gets a value indicating whether more events are available on the Exchange server.
no setter
NewWatermark → String?
Gets the subscription's new watermark.
no setter
PreviousWatermark → String?
Gets the subscription's previous watermark.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SubscriptionId → String?
Gets the Id of the subscription the collection is associated with.
no setter

Methods

LoadFromXml(EwsServiceXmlReader reader) → void
Loads from XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

XmlElementNameToEventTypeMap → Map<String, EventType>?
Gets the XML element name to event type mapping.
no setter