NotificationEventArgs class abstract

Provides data to a StreamingSubscriptionConnection's OnNotificationEvent event.

Constructors

NotificationEventArgs(StreamingSubscription subscription, Iterable<NotificationEvent> events)
Initializes a new instance of the

Properties

Events ↔ Iterable<NotificationEvent>?
Gets the events that were received.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Subscription ↔ StreamingSubscription?
Gets the subscription for which notifications have been received.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited