StreamingSubscription class

Represents a streaming subscription.
Inheritance

Constructors

StreamingSubscription(ExchangeService service)
Initializes a new instance of the
StreamingSubscription.witSubscriptionId(ExchangeService service, String subscriptionId)
Initializes a new instance with the specified subscription id, for continuing an existing subscription.

Properties

hashCode → int
The hash code for this object.
no setterinherited
Id ↔ String?
Gets the Id of the subscription.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Begins an asynchronous request to unsubscribe from the streaming subscription.
no setteroverride
UsesWatermark → bool
Gets a value indicating whether this subscription uses watermarks.
no setteroverride
Watermark ↔ String?
Gets the latest watermark of the subscription. Watermark is always null for streaming subscriptions.
getter/setter pairinherited

Methods

LoadFromXml(EwsServiceXmlReader reader) → Future<void>
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
Unsubscribe() → void
Unsubscribes from the streaming subscription.

Operators

operator ==(Object other) → bool
The equality operator.
inherited