SubscriptionBase class abstract

Represents the base class for event subscriptions.
Implementers

Constructors

SubscriptionBase(ExchangeService _service)
Initializes a new instance of the
SubscriptionBase.withId(ExchangeService _service, String id)
Initializes a new instance of the
SubscriptionBase.withIdAndWatermark(ExchangeService _service, String id, String watermark)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
Id ↔ String?
Gets the Id of the subscription.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Service → ExchangeService
Gets the session.
no setter
UsesWatermark → bool
Gets whether or not this subscription uses watermarks.
no setter
Watermark ↔ String?
Gets the latest watermark of the subscription. Watermark is always null for streaming subscriptions.
getter/setter pair

Methods

LoadFromXml(EwsServiceXmlReader reader) → Future<void>
Loads from XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited