SubscriptionErrorEventArgs class

Provides data to a StreamingSubscriptionConnection's OnSubscriptionError and OnDisconnect events.

Constructors

SubscriptionErrorEventArgs(StreamingSubscription subscription, Error exception)
Initializes a new instance of the

Properties

Exception ↔ Error?
Gets the exception representing the error. If Exception is null, the connection was cleanly closed by the server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Subscription ↔ StreamingSubscription?
Gets the subscription for which an error occurred. If Subscription is null, the error applies to the entire connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited