AttachmentsPropertyDefinition class

Represents base Attachments property type.
Inheritance

Constructors

AttachmentsPropertyDefinition()
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
IsNullable → bool
Gets a value indicating whether this property definition is for a nullable type (ref, int?, bool?...).
no setterinherited
Name ↔ String?
Gets the name of the property.
getter/setter pairinherited
propertyCreationDelegate ↔ ICreateComplexPropertyDelegate<AttachmentCollection>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type → Type
Gets the property type.
no setterinherited
Uri → String?
Gets the URI of the property definition.
no setterinherited
Version → ExchangeVersion?
Gets the minimum Exchange version that supports this property.
no setterinherited
XmlElementName → String?
Gets the name of the XML element.
no setterinherited

Methods

CreatePropertyInstance(ServiceObject? owner) → ComplexProperty
Creates the property instance.
inherited
GetAssociatedInternalProperties() → List<PropertyDefinition>
Gets a list of associated properties.
inherited
GetPrintableName() → String?
Gets the property definition's printable name.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
inherited
HasFlag(PropertyDefinitionFlags flag, ExchangeVersion version) → bool
Determines whether the specified flag is set.
override
HasFlagWithoutExchangeVersion(PropertyDefinitionFlags flag) → bool
Determines whether the specified flag is set.
inherited
InternalLoadFromXml(EwsServiceXmlReader reader, PropertyBag propertyBag) → void
Internals the load from XML.
inherited
LoadPropertyValueFromXml(EwsServiceXmlReader reader, PropertyBag propertyBag) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
RegisterAssociatedInternalProperties(List<PropertyDefinition> properties) → void
Registers associated properties.
inherited
toString() → String
Returns a
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WritePropertyValueToXml(EwsServiceXmlWriter writer, PropertyBag propertyBag, bool isUpdateOperation) → void
Writes to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited