BoolPropertyDefinition class

Represents Boolean property definition
Inheritance

Constructors

BoolPropertyDefinition(String xmlElementName, String uri, ExchangeVersion version)
Initializes a new instance of the
BoolPropertyDefinition.withFlagsAndNullable(String xmlElementName, String uri, List<PropertyDefinitionFlags> flags, ExchangeVersion version, bool isNullable)
Initializes a new instance of the
BoolPropertyDefinition.withUriAndFlags(String xmlElementName, String uri, List<PropertyDefinitionFlags> flags, ExchangeVersion version)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
IsNullable → bool
Gets a value indicating whether this property definition is for a nullable type (ref, int?, bool?...).
no setterinherited
isNullable ↔ bool
getter/setter pairinherited
Name ↔ String?
Gets the name of the property.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type → Type
Gets the property type.
no setterinherited
Uri → String?
Gets the URI of the property definition.
no setterinherited
Version → ExchangeVersion?
Gets the minimum Exchange version that supports this property.
no setterinherited
XmlElementName → String?
Gets the name of the XML element.
no setterinherited

Methods

GetAssociatedInternalProperties() → List<PropertyDefinition>
Gets a list of associated properties.
inherited
GetPrintableName() → String?
Gets the property definition's printable name.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
inherited
HasFlag(PropertyDefinitionFlags flag, ExchangeVersion version) → bool
Determines whether the specified flag is set.
inherited
HasFlagWithoutExchangeVersion(PropertyDefinitionFlags flag) → bool
Determines whether the specified flag is set.
inherited
LoadPropertyValueFromXml(EwsServiceXmlReader reader, PropertyBag propertyBag) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Parse(String? value) → Object?
Parses the specified value.
inherited
RegisterAssociatedInternalProperties(List<PropertyDefinition> properties) → void
Registers associated properties.
inherited
toString() → String
Returns a
inherited
toStringWithObject(Object value) → String
Convert instance to string.
override
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WritePropertyValueToXml(EwsServiceXmlWriter writer, PropertyBag propertyBag, bool isUpdateOperation) → void
Writes to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited