ByteArrayPropertyDefinition class

Represents byte array property definition.
Inheritance

Constructors

ByteArrayPropertyDefinition(String xmlElementName, String uri, List<PropertyDefinitionFlags> flags, ExchangeVersion version)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
IsNullable → bool
Converts byte array property to a string.
no setteroverride
isNullable ↔ bool
getter/setter pairinherited
Name ↔ String?
Gets the name of the property.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type → Type
Gets the property type.
no setteroverride
Uri → String?
Gets the URI of the property definition.
no setterinherited
Version → ExchangeVersion?
Gets the minimum Exchange version that supports this property.
no setterinherited
XmlElementName → String?
Gets the name of the XML element.
no setterinherited

Methods

GetAssociatedInternalProperties() → List<PropertyDefinition>
Gets a list of associated properties.
inherited
GetPrintableName() → String?
Gets the property definition's printable name.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
inherited
HasFlag(PropertyDefinitionFlags flag, ExchangeVersion version) → bool
Determines whether the specified flag is set.
inherited
HasFlagWithoutExchangeVersion(PropertyDefinitionFlags flag) → bool
Determines whether the specified flag is set.
inherited
LoadPropertyValueFromXml(EwsServiceXmlReader reader, PropertyBag propertyBag) → void
Loads from XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Parse(String? value) → Object
Parses the specified value.
override
RegisterAssociatedInternalProperties(List<PropertyDefinition> properties) → void
Registers associated properties.
inherited
toString() → String
Returns a
inherited
toStringWithObject(Object value) → String?
Convert instance to string.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WritePropertyValueToXml(EwsServiceXmlWriter writer, PropertyBag propertyBag, bool isUpdateOperation) → void
Writes to XML.
inherited
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited