ExtendedPropertyDefinition class

Represents the definition of an extended property.
Inheritance

Constructors

ExtendedPropertyDefinition([MapiPropertyType mapiType = MapiPropertyType.String])
Initializes a new instance of the
ExtendedPropertyDefinition.withDefaultPropertySetAndId(DefaultExtendedPropertySet? _propertySet, int? _id, MapiPropertyType? _mapiType)
Initializes a new instance of ExtendedPropertyDefinition.
ExtendedPropertyDefinition.withDefaultPropertySetAndName(DefaultExtendedPropertySet? _propertySet, String? _name, MapiPropertyType? _mapiType)
Initializes a new instance of the
ExtendedPropertyDefinition.withPropertySetIdAndId(Uuid? _propertySetId, int? _id, MapiPropertyType? _mapiType)
Initializes a new instance of the
ExtendedPropertyDefinition.withPropertySetIdAndName(Uuid? _propertySetId, String? _name, MapiPropertyType? _mapiType)
Initializes a new instance of the
ExtendedPropertyDefinition.withTag(int tag, MapiPropertyType? _mapiType)
Initializes a new instance of the

Properties

hashCode → int
Serves as a hash function for a particular type.
no setteroverride
Id → int?
Gets the Id of the extended property.
no setter
MapiType → MapiPropertyType?
Gets the MAPI type of the extended property.
no setter
Name → String?
Gets the name of the extended property.
no setter
PropertySet → DefaultExtendedPropertySet?
Gets the property set of the extended property.
no setter
PropertySetId → Uuid?
Gets the property set Id or the extended property.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Tag → int?
Gets the extended property's tag.
no setter
Type → Type?
Gets the property type.
no setteroverride
Version → ExchangeVersion
Gets the minimum Exchange version that supports this extended property.
no setteroverride

Methods

FormatField<T>(String name, T fieldValue) → String
Formats the field.
GetPrintableName() → String
Gets the property definition's printable name.
override
GetXmlElementName() → String
Gets the name of the XML element.
override
LoadFromXml(EwsServiceXmlReader reader) → void
Loads from XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
Determines whether two specified instances of ExtendedPropertyDefinition are equal.
override

Static Methods

IsEqualTo(ExtendedPropertyDefinition extPropDef1, ExtendedPropertyDefinition extPropDef2) → bool
Determines whether two specified instances of ExtendedPropertyDefinition are equal.