IndexedPropertyDefinition class

Represents an indexed property definition.
Inheritance

Constructors

IndexedPropertyDefinition(String? uri, String? index)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setteroverride
Index → String?
Gets the index of the property.
no setter
index ↔ String?
Index attribute of IndexedFieldURI element.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type → Type
Gets the property type.
no setteroverride
Uri → String?
Gets the URI of the property definition.
no setterinherited
Version → ExchangeVersion?
Gets the minimum Exchange version that supports this property.
no setterinherited

Methods

GetPrintableName() → String
Gets the property definition's printable name.
override
GetXmlElementName() → String
Gets the name of the XML element.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
Determines whether two specified instances of IndexedPropertyDefinition are equal.
override

Static Methods

IsEqualTo(IndexedPropertyDefinition idxPropDef1, IndexedPropertyDefinition idxPropDef2) → bool
Determines whether two specified instances of IndexedPropertyDefinition are equal.