ServiceObjectPropertyDefinition class abstract

Represents a property definition for a service object.
Inheritance
Implementers

Constructors

ServiceObjectPropertyDefinition()
Initializes a new instance of the
ServiceObjectPropertyDefinition.withUri(String? uri)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type → Type?
Gets the type of the property.
no setterinherited
Uri → String?
Gets the URI of the property definition.
no setter
Version → ExchangeVersion?
Gets the minimum Exchange version that supports this property.
no setteroverride

Methods

GetPrintableName() → String?
Gets the property definition's printable name.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited