TypedPropertyDefinition class abstract

Represents typed property definition.
Inheritance
Implementers

Constructors

TypedPropertyDefinition.withUri(String xmlElementName, String uri, ExchangeVersion version)
Initializes a new instance of the
TypedPropertyDefinition.withUriAndFlags(String xmlElementName, String uri, List<PropertyDefinitionFlags> flags, ExchangeVersion version)
Initializes a new instance of the
TypedPropertyDefinition.withUriAndFlagsAndNullable(String xmlElementName, String uri, List<PropertyDefinitionFlags> flags, ExchangeVersion version, bool isNullable)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
IsNullable → bool
Gets a value indicating whether this property definition is for a nullable type (ref, int?, bool?...).
no setteroverride
isNullable ↔ bool
getter/setter pair
Name ↔ String?
Gets the name of the property.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type → Type?
Gets the type of the property.
no setterinherited
Uri → String?
Gets the URI of the property definition.
no setterinherited
Version → ExchangeVersion?
Gets the minimum Exchange version that supports this property.
no setterinherited
XmlElementName → String?
Gets the name of the XML element.
no setterinherited

Methods

GetAssociatedInternalProperties() → List<PropertyDefinition>
Gets a list of associated properties.
inherited
GetPrintableName() → String?
Gets the property definition's printable name.
inherited
GetXmlElementName() → String
Gets the name of the XML element.
inherited
HasFlag(PropertyDefinitionFlags flag, ExchangeVersion version) → bool
Determines whether the specified flag is set.
inherited
HasFlagWithoutExchangeVersion(PropertyDefinitionFlags flag) → bool
Determines whether the specified flag is set.
inherited
LoadPropertyValueFromXml(EwsServiceXmlReader reader, PropertyBag propertyBag) → void
Loads from XML.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Parse(String? value) → Object?
Parses the specified value.
RegisterAssociatedInternalProperties(List<PropertyDefinition> properties) → void
Registers associated properties.
inherited
toString() → String
Returns a
inherited
toStringWithObject(Object value) → String?
Convert instance to string.
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WritePropertyValueToXml(EwsServiceXmlWriter writer, PropertyBag propertyBag, bool isUpdateOperation) → void
Writes to XML.
override
WriteToXml(EwsServiceXmlWriter writer) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited