CalendarView class

Represents a date range view of appointments in calendar folder search operations.
Inheritance

Constructors

CalendarView(DateTime startDate, DateTime endDate)
Initializes a new instance of CalendarView.
CalendarView.withMaxItemsReturned(DateTime startDate, DateTime endDate, int maxItemsReturned)
Initializes a new instance of CalendarView.

Properties

EndDate ↔ DateTime?
Gets or sets the end date.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
MaxItemsReturned ↔ int?
The maximum number of items the search operation should return.
getter/setter pair
PropertySet ↔ PropertySet?
Gets or sets the property set. PropertySet determines which properties will be loaded on found items. If PropertySet is null, all first class properties are loaded on found items.
getter/setter pairinherited
propertySet ↔ PropertySet?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
StartDate ↔ DateTime?
Gets or sets the start date.
getter/setter pair
Traversal ↔ ItemTraversal
Gets or sets the search traversal mode. Defaults to ItemTraversal.Shallow.
getter/setter pair

Methods

GetMaxEntriesReturned() → int?
Gets the maximum number of items or folders the search operation should return.
override
GetPropertySetOrDefault() → PropertySet
Gets the property set or the default.
inherited
GetServiceObjectType() → ServiceObjectType
Gets the type of service object this view applies to.
override
GetViewXmlElementName() → String
Gets the name of the view XML element.
override
InternalValidate(ServiceRequestBase request) → void
Validate instance.
override
InternalWriteSearchSettingsToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Writes the search settings to XML.
override
InternalWriteViewToXml(EwsServiceXmlWriter writer) → void
Write to XML.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteOrderByToXml(EwsServiceXmlWriter writer) → void
Writes OrderBy property to XML.
override
WriteToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited