SearchFilterCollection class

Represents a collection of search filters linked by a logical operator. Applications can use SearchFilterCollection to define complex search filters such as "Condition1 AND Condition2".
Inheritance
Implemented types
Mixed-in types

Constructors

SearchFilterCollection()
Initializes a new instance of the
SearchFilterCollection.withOperator(LogicalOperator logicalOperator)
Initializes a new instance of the
SearchFilterCollection.withOperatorAndSearchFilters(LogicalOperator logicalOperator, List<SearchFilter> searchFilters)
Initializes a new instance of the

Properties

Count → int
Gets the total number of search filters in the collection.
no setter
first → SearchFilter
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<SearchFilter>
Gets an enumerator that iterates through the elements of the collection.
no setteroverride
last → SearchFilter
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
LogicalOperator ↔ LogicalOperator
Gets or sets the logical operator that links the serach filters in this collection.
getter/setter pair
Namespace ↔ XmlNamespace
Gets or sets the namespace.
getter/setter pairinherited
OnChangeList ↔ List<IComplexPropertyChangedDelegate>
Occurs when property changed.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → SearchFilter
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

Add(SearchFilter? searchFilter) → void
Adds a search filter of any type to the collection.
addOnChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
AddRange(Iterable<SearchFilter> searchFilters) → void
Adds multiple search filters to the collection.
any(bool test(SearchFilter element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
CanSetFieldValue<T>(T field, T value) → bool
Sets value of field.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
Changed() → dynamic
Instance was changed.
inherited
Clear() → void
Clears the collection.
ClearChangeLog() → void
Clears the change log.
inherited
Contains(SearchFilter searchFilter) → bool
Determines whether a specific search filter is in the collection.
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → SearchFilter
Returns the indexth element.
inherited
every(bool test(SearchFilter element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(SearchFilter element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(SearchFilter element), {SearchFilter orElse()?}) → SearchFilter
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, SearchFilter element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<SearchFilter> other) → Iterable<SearchFilter>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(SearchFilter element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
GetXmlElementName() → String?
Gets the name of the XML element.
override
InternalValidate() → void
Validate instance.
override
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(SearchFilter element), {SearchFilter orElse()?}) → SearchFilter
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsServiceXmlReader reader, String? xmlElementName) → void
Loads from XML.
inherited
LoadFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String? xmlElementName) → void
Loads from XML.
inherited
map<T>(T toElement(SearchFilter e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ReadAttributesFromXml(EwsServiceXmlReader reader) → void
Reads the attributes from XML.
inherited
ReadTextValueFromXml(EwsServiceXmlReader reader) → void
Reads the text value from XML.
inherited
reduce(SearchFilter combine(SearchFilter value, SearchFilter element)) → SearchFilter
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
Remove(SearchFilter searchFilter) → void
Removes a search filter from the collection.
RemoveAt(int index) → void
Removes the search filter at the specified index from the collection.
removeChangeEvent(IComplexPropertyChangedDelegate change) → void
inherited
SearchFilterChanged(ComplexProperty complexProperty) → void
A search filter has changed.
singleWhere(bool test(SearchFilter element), {SearchFilter orElse()?}) → SearchFilter
The single element that satisfies test.
inherited
skip(int count) → Iterable<SearchFilter>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(SearchFilter element)) → Iterable<SearchFilter>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<SearchFilter>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(SearchFilter element)) → Iterable<SearchFilter>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<SearchFilter>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<SearchFilter>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryReadElementFromXml(EwsServiceXmlReader reader) → bool
Tries to read element from XML.
override
TryReadElementFromXmlToPatch(EwsServiceXmlReader reader) → bool
Tries to read element from XML to patch this property.
inherited
UpdateFromXml(EwsServiceXmlReader reader, String xmlElementName) → void
Loads from XML to update this property.
inherited
UpdateFromXmlWithNamespace(EwsServiceXmlReader reader, XmlNamespace xmlNamespace, String xmlElementName) → void
Loads from XML to update itself.
inherited
Validate() → void
Implements ISelfValidate.Validate. Validates this instance.
inherited
where(bool test(SearchFilter element)) → Iterable<SearchFilter>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteElementsToXml(EwsServiceXmlWriter writer) → void
Writes the elements to XML.
override
WriteToXml(EwsServiceXmlWriter writer, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithNamespace(EwsServiceXmlWriter writer, XmlNamespace xmlNamespace, String? xmlElementName) → void
Writes to XML.
inherited
WriteToXmlWithWriter(EwsServiceXmlWriter writer) → void
Writes to XML.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → SearchFilter
Gets or sets the search filter at the specified index.
operator []=(int index, SearchFilter value) → void