ItemGroup<TItem extends Item> class

Represents a group of items as returned by grouped item search operations.

Constructors

ItemGroup(String? groupIndex, List<TItem>? items)
Initializes a new instance of the

Properties

GroupIndex ↔ String?
Gets an index identifying the group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Items ↔ List<TItem>?
Gets a collection of the items in this group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited