ItemView class

Represents the view settings in a folder search operation.
Inheritance

Constructors

ItemView.withPageSize(int pageSize)
Initializes a new instance of the
ItemView.withPageSizeAndOffset(int pageSize, int offset)
Initializes a new instance of the
ItemView.withPageSizeAndOffsetAndBasePoint(int pageSize, int offset, OffsetBasePoint offsetBasePoint)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
Offset ↔ int
Gets or sets the offset.
getter/setter pairinherited
OffsetBasePoint ↔ OffsetBasePoint
Gets or sets the base point of the offset.
getter/setter pairinherited
OrderBy → OrderByCollection
Gets the properties against which the returned items should be ordered.
no setter
PageSize ↔ int
The maximum number of items or folders the search operation should return.
getter/setter pairinherited
PropertySet ↔ PropertySet?
Gets or sets the property set. PropertySet determines which properties will be loaded on found items. If PropertySet is null, all first class properties are loaded on found items.
getter/setter pairinherited
propertySet ↔ PropertySet?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Traversal ↔ ItemTraversal
Gets or sets the search traversal mode. Defaults to ItemTraversal.Shallow.
getter/setter pair

Methods

GetMaxEntriesReturned() → int
Gets the maximum number of items or folders the search operation should return.
inherited
GetPropertySetOrDefault() → PropertySet
Gets the property set or the default.
inherited
GetServiceObjectType() → ServiceObjectType
Gets the type of service object this view applies to.
override
GetViewXmlElementName() → String
Gets the name of the view XML element.
override
InternalValidate(ServiceRequestBase request) → void
Validates this view.
override
InternalWriteSearchSettingsToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Internals the write search settings to XML.
override
InternalWriteViewToXml(EwsServiceXmlWriter writer) → void
Write to XML.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
override
WriteOrderByToXml(EwsServiceXmlWriter writer) → void
Writes OrderBy property to XML.
override
WriteToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited