OrderByCollection class

Represents an ordered collection of property definitions qualified with a sort direction.
Implemented types
Mixed-in types

Constructors

OrderByCollection()
Initializes a new instance of the

Properties

Count → int
Gets the number of elements contained in the collection.
no setter
first → MapEntry<PropertyDefinitionBase, SortDirection>
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<MapEntry<PropertyDefinitionBase, SortDirection>>
Returns an enumerator that iterates through the collection.
no setteroverride
last → MapEntry<PropertyDefinitionBase, SortDirection>
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → MapEntry<PropertyDefinitionBase, SortDirection>
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

Add(PropertyDefinitionBase propertyDefinition, SortDirection sortDirection) → void
Adds the specified property definition / sort direction pair to the collection.
any(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
Clear() → void
Removes all elements from the collection.
Contains(PropertyDefinitionBase propertyDefinition) → bool
Determines whether the collection contains the specified property definition.
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → MapEntry<PropertyDefinitionBase, SortDirection>
Returns the indexth element.
inherited
every(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(MapEntry<PropertyDefinitionBase, SortDirection> element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element), {MapEntry<PropertyDefinitionBase, SortDirection> orElse()?}) → MapEntry<PropertyDefinitionBase, SortDirection>
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, MapEntry<PropertyDefinitionBase, SortDirection> element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<MapEntry<PropertyDefinitionBase, SortDirection>> other) → Iterable<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(MapEntry<PropertyDefinitionBase, SortDirection> element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element), {MapEntry<PropertyDefinitionBase, SortDirection> orElse()?}) → MapEntry<PropertyDefinitionBase, SortDirection>
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(MapEntry<PropertyDefinitionBase, SortDirection> e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(MapEntry<PropertyDefinitionBase, SortDirection> combine(MapEntry<PropertyDefinitionBase, SortDirection> value, MapEntry<PropertyDefinitionBase, SortDirection> element)) → MapEntry<PropertyDefinitionBase, SortDirection>
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
Remove(PropertyDefinitionBase propertyDefinition) → bool
Removes the specified property definition from the collection.
RemoveAt(int index) → void
Removes the element at the specified index from the collection.
singleWhere(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element), {MapEntry<PropertyDefinitionBase, SortDirection> orElse()?}) → MapEntry<PropertyDefinitionBase, SortDirection>
The single element that satisfies test.
inherited
skip(int count) → Iterable<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element)) → Iterable<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element)) → Iterable<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
TryGetValue(PropertyDefinitionBase propertyDefinition, OutParam<SortDirection> sortDirectionOutParam) → bool
Tries to get the value for a property definition in the collection.
where(bool test(MapEntry<PropertyDefinitionBase, SortDirection> element)) → Iterable<MapEntry<PropertyDefinitionBase, SortDirection>>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
WriteToXml(EwsServiceXmlWriter writer, String xmlElementName) → void
Writes to XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → MapEntry<PropertyDefinitionBase, SortDirection>
Gets the element at the specified index from the collection.