PagedView class abstract

Represents a view settings that support paging in a search operation.
Inheritance
Implementers

Constructors

PagedView.withPageSize(int pageSize)
Initializes a new instance of the
PagedView.withPageSizeAndOffset(int pageSize, int offset)
Initializes a new instance of the
PagedView.withPageSizeAndOffsetAndBasePoint(int pageSize, int offset, OffsetBasePoint offsetBasePoint)
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
Offset ↔ int
Gets or sets the offset.
getter/setter pair
OffsetBasePoint ↔ OffsetBasePoint
Gets or sets the base point of the offset.
getter/setter pair
PageSize ↔ int
The maximum number of items or folders the search operation should return.
getter/setter pair
PropertySet ↔ PropertySet?
Gets or sets the property set. PropertySet determines which properties will be loaded on found items. If PropertySet is null, all first class properties are loaded on found items.
getter/setter pairinherited
propertySet ↔ PropertySet?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

GetMaxEntriesReturned() → int
Gets the maximum number of items or folders the search operation should return.
override
GetPropertySetOrDefault() → PropertySet
Gets the property set or the default.
inherited
GetServiceObjectType() → ServiceObjectType?
Gets the type of service object this view applies to.
inherited
GetViewXmlElementName() → String
Gets the name of the view XML element.
inherited
InternalValidate(ServiceRequestBase request) → void
Validates this view.
override
InternalWriteSearchSettingsToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Internals the write search settings to XML.
override
InternalWriteViewToXml(EwsServiceXmlWriter writer) → void
Write to XML.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
inherited
WriteOrderByToXml(EwsServiceXmlWriter writer) → void
Writes OrderBy property to XML.
override
WriteToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Writes to XML.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited