ViewBase class abstract

Represents the base view class for search operations.
Implementers

Constructors

ViewBase()
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
PropertySet ↔ PropertySet?
Gets or sets the property set. PropertySet determines which properties will be loaded on found items. If PropertySet is null, all first class properties are loaded on found items.
getter/setter pair
propertySet ↔ PropertySet?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

GetMaxEntriesReturned() → int?
Gets the maximum number of items or folders the search operation should return.
GetPropertySetOrDefault() → PropertySet
Gets the property set or the default.
GetServiceObjectType() → ServiceObjectType?
Gets the type of service object this view applies to.
GetViewXmlElementName() → String
Gets the name of the view XML element.
InternalValidate(ServiceRequestBase request) → void
Validates this view.
InternalWriteSearchSettingsToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Writes the search settings to XML.
InternalWriteViewToXml(EwsServiceXmlWriter writer) → void
Writes this view to XML.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteAttributesToXml(EwsServiceXmlWriter writer) → void
Writes the attributes to XML.
WriteOrderByToXml(EwsServiceXmlWriter writer) → void
Writes OrderBy property to XML.
WriteToXml(EwsServiceXmlWriter writer, Grouping? groupBy) → void
Writes to XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited