Change class abstract

Represents a change as returned by a synchronization operation.
Implementers

Constructors

Change()
Initializes a new instance of Change.

Properties

ChangeType ↔ ChangeType?
Gets the type of the change.
getter/setter pair
changeType ↔ ChangeType?
The type of change.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Id ↔ ServiceId?
Gets or sets the Id of the service object the change applies to.
getter/setter pair
id ↔ ServiceId?
The Id of the service object the change applies to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ServiceObject ↔ ServiceObject?
Gets or sets the service object the change applies to.
getter/setter pair
serviceObject ↔ ServiceObject?
The service object the change applies to.
getter/setter pair

Methods

CreateId() → ServiceId
Creates an Id of the appropriate class.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited