ItemChange class

Represents a change on an item as returned by a synchronization operation.
Inheritance

Constructors

ItemChange()
Initializes a new instance of ItemChange.

Properties

ChangeType ↔ ChangeType?
Gets the type of the change.
getter/setter pairinherited
changeType ↔ ChangeType?
The type of change.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
Id ↔ ServiceId?
Gets or sets the Id of the service object the change applies to.
getter/setter pairinherited
id ↔ ServiceId?
The Id of the service object the change applies to.
getter/setter pairinherited
IsRead ↔ bool?
Gets the IsRead property for the item that the change applies to. IsRead is only valid when ChangeType is equal to ChangeType.ReadFlagChange.
getter/setter pair
Item → Item?
Gets the item the change applies to. Item is null when ChangeType is equal to either ChangeType.Delete or ChangeType.ReadFlagChange. In those cases, use the ItemId property to retrieve the Id of the item that was deleted or whose IsRead property changed.
no setter
ItemId → ItemId?
Gets the Id of the item the change applies to.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ServiceObject ↔ ServiceObject?
Gets or sets the service object the change applies to.
getter/setter pairinherited
serviceObject ↔ ServiceObject?
The service object the change applies to.
getter/setter pairinherited

Methods

CreateId() → ServiceId
Creates an ItemId instance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited