XmlReader class

Constructors

XmlReader(String data)

Properties

AttributeCount → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
IsEmptyElement → bool
no setter
LocalName → dynamic
no setter
Name → String
no setter
NamespaceURI → dynamic
no setter
NodeType → XmlNodeType?
no setter
Prefix → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Value → String
no setter

Methods

GetAttribute(String attributeName) → String?
GetAttributeWithNamespace(String attributeName, String namespace) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Read() → bool
ReadInnerXml() → String
ReadOuterXml() → String
ReadString() → String
ReadSubtree() → XmlReader
ReadToDescendant(String localName, String getNamespaceUri) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Create(Stream<List<int>> inputStream) → Future<XmlReader>