XmlElementBuilder class

Inheritance

Constructors

XmlElementBuilder()

Properties

attributes → List<XmlAttribute>
final
children → List<XmlNode>
final
hashCode → int
The hash code for this object.
no setterinherited
isSelfClosing ↔ bool
getter/setter pair
name ↔ XmlName
getter/setter pair
namespaces → Map<String?, NamespaceData>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → XmlNode
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited