XmlNodeBuilder class abstract

Implementers

Constructors

XmlNodeBuilder()

Properties

attributes → List<XmlAttribute>
no setter
children → List<XmlNode>
no setter
hashCode → int
The hash code for this object.
no setterinherited
namespaces → Map<String?, NamespaceData>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → XmlNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited