AbstractItemIdWrapper class abstract

Represents the abstraction of an item Id.
Implementers

Constructors

AbstractItemIdWrapper()
Initializes a new instance of the

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

GetItem() → Item?
Obtains the ItemBase object associated with the wrapper.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteToXml(EwsServiceXmlWriter writer) → void
Writes the Id encapsulated in the wrapper to XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited