FolderIdWrapperList class

Represents a list a abstracted folder Ids.
Implemented types
Mixed-in types

Constructors

FolderIdWrapperList()

Properties

Count → int
Gets the id count.
no setter
first → AbstractFolderIdWrapper
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<AbstractFolderIdWrapper>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → AbstractFolderIdWrapper
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → AbstractFolderIdWrapper
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

Add(Folder folder) → void
Adds the specified folder.
AddFolderId(FolderId? folderId) → void
Adds the specified folder id.
AddRange(Iterable<Folder> folders) → void
Adds the range.
AddRangeFolderIds(Iterable<FolderId?>? folderIds) → void
Adds the range of folder ids.
any(bool test(AbstractFolderIdWrapper element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → AbstractFolderIdWrapper
Returns the indexth element.
inherited
every(bool test(AbstractFolderIdWrapper element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(AbstractFolderIdWrapper element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(AbstractFolderIdWrapper element), {AbstractFolderIdWrapper orElse()?}) → AbstractFolderIdWrapper
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, AbstractFolderIdWrapper element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<AbstractFolderIdWrapper> other) → Iterable<AbstractFolderIdWrapper>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(AbstractFolderIdWrapper element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(AbstractFolderIdWrapper element), {AbstractFolderIdWrapper orElse()?}) → AbstractFolderIdWrapper
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(AbstractFolderIdWrapper e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(AbstractFolderIdWrapper combine(AbstractFolderIdWrapper value, AbstractFolderIdWrapper element)) → AbstractFolderIdWrapper
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(AbstractFolderIdWrapper element), {AbstractFolderIdWrapper orElse()?}) → AbstractFolderIdWrapper
The single element that satisfies test.
inherited
skip(int count) → Iterable<AbstractFolderIdWrapper>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(AbstractFolderIdWrapper element)) → Iterable<AbstractFolderIdWrapper>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<AbstractFolderIdWrapper>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(AbstractFolderIdWrapper element)) → Iterable<AbstractFolderIdWrapper>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<AbstractFolderIdWrapper>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<AbstractFolderIdWrapper>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
Validate(ExchangeVersion version) → void
Validates list of folderIds against a specified request version.
where(bool test(AbstractFolderIdWrapper element)) → Iterable<AbstractFolderIdWrapper>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited
WriteToXml(EwsServiceXmlWriter writer, XmlNamespace ewsNamesapce, String xmlElementName) → void
Writes to XML.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → AbstractFolderIdWrapper
Gets the