ItemWrapper class

Represents an item Id provided by a ItemBase object.
Inheritance

Constructors

ItemWrapper(Item item)
Initializes a new instance of ItemWrapper.

Properties

hashCode → int
The hash code for this object.
no setterinherited
item ↔ Item?
The ItemBase object providing the Id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

GetItem() → Item?
Obtains the ItemBase object associated with the wrapper.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
WriteToXml(EwsServiceXmlWriter writer) → void
Writes the Id encapsulated in the wrapper to XML.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited