MapiTypeConverterMapEntry class

Represents an entry in the MapiTypeConverter map.

Constructors

MapiTypeConverterMapEntry(Type type)
Initializes a new instance of the

Properties

ConvertToString ↔ Func<Object, String>
Gets or sets the String to object converter.
getter/setter pair
DefaultValue → Object?
Gets the default value for the type.
no setter
hashCode → int
The hash code for this object.
no setterinherited
IsArray ↔ bool
Gets or sets a value indicating whether this instance is array.
getter/setter pair
Parse ↔ Func<String?, Object?>
Gets or sets the String parser.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type ↔ Type?
Gets or sets the type.
getter/setter pair

Methods

ChangeType(Object? value) → Object?
Change value to a value of compatible type.
ConvertToValue(String? stringValue) → Object?
Change value to a value of compatible type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
ValidateValueAsArray(Object? value) → void
Converts a String to value consistent with type (or uses the default value if the String is null or empty).

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultValueMap ↔ LazyMember<Map<Type, Object?>>
Map CLR types used for MAPI properties to matching default values.
getter/setter pair