NameResolutionCollection class

Represents a list of suggested name resolutions.
Implemented types
Mixed-in types

Constructors

NameResolutionCollection(ExchangeService service)
Initializes a new instance of the

Properties

Count → int
Gets the total number of elements in the list.
no setter
first → NameResolution
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
IncludesAllResolutions → bool?
Gets a value indicating whether more suggested resolutions are available. ResolveName only returns a maximum of 100 name resolutions. When IncludesAllResolutions is false, there were more than 100 matching names on the server. To narrow the search, provide a more precise name to ResolveName.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<NameResolution>
Gets an enumerator that iterates through the elements of the collection.
no setteroverride
last → NameResolution
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Session → ExchangeService?
Gets the session.
no setter
single → NameResolution
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(NameResolution element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → NameResolution
Returns the indexth element.
inherited
every(bool test(NameResolution element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(NameResolution element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(NameResolution element), {NameResolution orElse()?}) → NameResolution
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, NameResolution element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<NameResolution> other) → Iterable<NameResolution>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(NameResolution element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(NameResolution element), {NameResolution orElse()?}) → NameResolution
The last element that satisfies the given predicate test.
inherited
LoadFromXml(EwsServiceXmlReader reader) → void
Loads from XML.
map<T>(T toElement(NameResolution e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(NameResolution combine(NameResolution value, NameResolution element)) → NameResolution
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(NameResolution element), {NameResolution orElse()?}) → NameResolution
The single element that satisfies test.
inherited
skip(int count) → Iterable<NameResolution>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(NameResolution element)) → Iterable<NameResolution>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<NameResolution>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(NameResolution element)) → Iterable<NameResolution>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<NameResolution>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<NameResolution>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(NameResolution element)) → Iterable<NameResolution>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → NameResolution
Gets the name resolution at the specified index.