Time class

Represents a time.

Constructors

Time()
Initializes a new instance of Time.
Time.fromDateTime(DateTime dateTime)
Initializes a new instance of Time.
Time.fromMinutes(int minutes)
Initializes a new instance of Time.
Time.fromParts(int hours, int minutes, int seconds)
Initializes a new instance of Time.

Properties

hashCode → int
The hash code for this object.
no setterinherited
Hours ↔ int
Gets or sets the hours.
getter/setter pair
hours ↔ int
getter/setter pair
Minutes ↔ int
Gets or sets the minutes.
getter/setter pair
minutes ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Seconds ↔ int
Gets or sets the seconds.
getter/setter pair
seconds ↔ int
getter/setter pair

Methods

ConvertToMinutes() → int
Converts the time into a number of minutes since 12:00AM.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
ToXSTime() → String
Convert Time to XML Schema time.

Operators

operator ==(Object other) → bool
The equality operator.
inherited